@@ -28,7 +28,7 @@ MapMat<eT>::~MapMat()
   if(map_ptr)  { (*map_ptr).clear();  delete map_ptr; }
   
   // try to expose buggy user code that accesses deleted objects
-  if(arma_config::debug)  { map_ptr = NULL; }
+  if(arma_config::debug)  { map_ptr = nullptr; }
   
   arma_type_check(( is_supported_elem_type<eT>::value == false ));
   }
@@ -41,7 +41,7 @@ MapMat<eT>::MapMat()
   : n_rows (0)
   , n_cols (0)
   , n_elem (0)
-  , map_ptr(NULL)
+  , map_ptr(nullptr)
   {
   arma_extra_debug_sigprint_this(this);
   
@@ -56,7 +56,7 @@ MapMat<eT>::MapMat(const uword in_n_rows, const uword in_n_cols)
   : n_rows (in_n_rows)
   , n_cols (in_n_cols)
   , n_elem (in_n_rows * in_n_cols)
-  , map_ptr(NULL)
+  , map_ptr(nullptr)
   {
   arma_extra_debug_sigprint_this(this);
   
@@ -71,7 +71,7 @@ MapMat<eT>::MapMat(const SizeMat& s)
   : n_rows (s.n_rows)
   , n_cols (s.n_cols)
   , n_elem (s.n_rows * s.n_cols)
-  , map_ptr(NULL)
+  , map_ptr(nullptr)
   {
   arma_extra_debug_sigprint_this(this);
   
@@ -86,7 +86,7 @@ MapMat<eT>::MapMat(const MapMat<eT>& x)
   : n_rows (0)
   , n_cols (0)
   , n_elem (0)
-  , map_ptr(NULL)
+  , map_ptr(nullptr)
   {
   arma_extra_debug_sigprint_this(this);
   
@@ -121,7 +121,7 @@ MapMat<eT>::MapMat(const SpMat<eT>& x)
   : n_rows (0)
   , n_cols (0)
   , n_elem (0)
-  , map_ptr(NULL)
+  , map_ptr(nullptr)
   {
   arma_extra_debug_sigprint_this(this);
   
@@ -164,60 +164,52 @@ MapMat<eT>::operator=(const SpMat<eT>& x)
       
       const uword index = (x_n_rows * col) + row;
       
-      #if defined(ARMA_USE_CXX11)
-        map_ref.emplace_hint(map_ref.cend(), index, val);
-      #else
-        map_ref.operator[](index) = val;
-      #endif
+      map_ref.emplace_hint(map_ref.cend(), index, val);
       }
     }
   }
 
 
 
-#if defined(ARMA_USE_CXX11)
+template<typename eT>
+inline
+MapMat<eT>::MapMat(MapMat<eT>&& x)
+  : n_rows (x.n_rows )
+  , n_cols (x.n_cols )
+  , n_elem (x.n_elem )
+  , map_ptr(x.map_ptr)
+  {
+  arma_extra_debug_sigprint_this(this);
+  
+  access::rw(x.n_rows)  = 0;
+  access::rw(x.n_cols)  = 0;
+  access::rw(x.n_elem)  = 0;
+  access::rw(x.map_ptr) = nullptr;
+  }
 
-  template<typename eT>
-  inline
-  MapMat<eT>::MapMat(MapMat<eT>&& x)
-    : n_rows (x.n_rows )
-    , n_cols (x.n_cols )
-    , n_elem (x.n_elem )
-    , map_ptr(x.map_ptr)
-    {
-    arma_extra_debug_sigprint_this(this);
-    
-    access::rw(x.n_rows)  = 0;
-    access::rw(x.n_cols)  = 0;
-    access::rw(x.n_elem)  = 0;
-    access::rw(x.map_ptr) = NULL;
-    }
-  
-  
-  
-  template<typename eT>
-  inline
-  void
-  MapMat<eT>::operator=(MapMat<eT>&& x)
-    {
-    arma_extra_debug_sigprint();
-    
-    reset();
-    
-    if(map_ptr)  { delete map_ptr; }
-    
-    access::rw(n_rows)  = x.n_rows;
-    access::rw(n_cols)  = x.n_cols;
-    access::rw(n_elem)  = x.n_elem;
-    access::rw(map_ptr) = x.map_ptr;
-    
-    access::rw(x.n_rows)  = 0;
-    access::rw(x.n_cols)  = 0;
-    access::rw(x.n_elem)  = 0;
-    access::rw(x.map_ptr) = NULL;
-    }
 
-#endif
+
+template<typename eT>
+inline
+void
+MapMat<eT>::operator=(MapMat<eT>&& x)
+  {
+  arma_extra_debug_sigprint();
+  
+  reset();
+  
+  if(map_ptr)  { delete map_ptr; }
+  
+  access::rw(n_rows)  = x.n_rows;
+  access::rw(n_cols)  = x.n_cols;
+  access::rw(n_elem)  = x.n_elem;
+  access::rw(map_ptr) = x.map_ptr;
+  
+  access::rw(x.n_rows)  = 0;
+  access::rw(x.n_cols)  = 0;
+  access::rw(x.n_elem)  = 0;
+  access::rw(x.map_ptr) = nullptr;
+  }
 
 
 
@@ -356,11 +348,7 @@ MapMat<eT>::eye(const uword in_n_rows, const uword in_n_cols)
     {
     const uword index = (in_n_rows * i) + i;
     
-    #if defined(ARMA_USE_CXX11)
-      map_ref.emplace_hint(map_ref.cend(), index, eT(1));
-    #else
-      map_ref.operator[](index) = eT(1);
-    #endif
+    map_ref.emplace_hint(map_ref.cend(), index, eT(1));
     }
   }
 
@@ -619,11 +607,7 @@ MapMat<eT>::sprandu(const uword in_n_rows, const uword in_n_cols, const double d
     const uword index = indx_mem[i];
     const eT    val   = vals_mem[i];
     
-    #if defined(ARMA_USE_CXX11)
-      map_ref.emplace_hint(map_ref.cend(), index, val);
-    #else
-      map_ref.operator[](index) = val;
-    #endif
+    map_ref.emplace_hint(map_ref.cend(), index, val);
     }
   }
 
@@ -744,10 +728,10 @@ MapMat<eT>::init_cold()
   
   // ensure that n_elem can hold the result of (n_rows * n_cols)
   
-  #if (defined(ARMA_USE_CXX11) || defined(ARMA_64BIT_WORD))
+  #if defined(ARMA_64BIT_WORD)
     const char* error_message = "MapMat(): requested size is too large";
   #else
-    const char* error_message = "MapMat(): requested size is too large; suggest to compile in C++11 mode or enable ARMA_64BIT_WORD";
+    const char* error_message = "MapMat(): requested size is too large; suggest to enable ARMA_64BIT_WORD";
   #endif
   
   arma_debug_check
@@ -762,7 +746,7 @@ MapMat<eT>::init_cold()
   
   map_ptr = new (std::nothrow) map_type;
   
-  arma_check_bad_alloc( (map_ptr == NULL), "MapMat(): out of memory" );
+  arma_check_bad_alloc( (map_ptr == nullptr), "MapMat(): out of memory" );
   }
 
 
@@ -778,10 +762,10 @@ MapMat<eT>::init_warm(const uword in_n_rows, const uword in_n_cols)
   
   // ensure that n_elem can hold the result of (n_rows * n_cols)
   
-  #if (defined(ARMA_USE_CXX11) || defined(ARMA_64BIT_WORD))
+  #if defined(ARMA_64BIT_WORD)
     const char* error_message = "MapMat(): requested size is too large";
   #else
-    const char* error_message = "MapMat(): requested size is too large; suggest to compile in C++11 mode or enable ARMA_64BIT_WORD";
+    const char* error_message = "MapMat(): requested size is too large; suggest to enable ARMA_64BIT_WORD";
   #endif
   
   arma_debug_check
@@ -814,24 +798,16 @@ MapMat<eT>::set_val(const uword index, const eT& in_val)
   
   if(in_val != eT(0))
     {
-    #if defined(ARMA_USE_CXX11)
+    map_type& map_ref = (*map_ptr);
+    
+    if( (map_ref.empty() == false) && (index > uword(map_ref.crbegin()->first)) )
       {
-      map_type& map_ref = (*map_ptr);
-      
-      if( (map_ref.empty() == false) && (index > uword(map_ref.crbegin()->first)) )
-        {
-        map_ref.emplace_hint(map_ref.cend(), index, in_val);
-        }
-      else
-        {
-        map_ref.operator[](index) = in_val;
-        }
+      map_ref.emplace_hint(map_ref.cend(), index, in_val);
       }
-    #else
+    else
       {
-      (*map_ptr).operator[](index) = in_val;
+      map_ref.operator[](index) = in_val;
       }
-    #endif
     }
   else
     {
@@ -1204,7 +1180,7 @@ SpMat_MapMat_val<eT>::operator=(const eT in_val)
       (*this).set(in_val);
       }
     }
-  #elif (defined(ARMA_USE_CXX11) && !defined(ARMA_DONT_USE_CXX11_MUTEX))
+  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
     {
     s_parent.cache_mutex.lock();
     
@@ -1239,7 +1215,7 @@ SpMat_MapMat_val<eT>::operator+=(const eT in_val)
       (*this).add(in_val);
       }
     }
-  #elif (defined(ARMA_USE_CXX11) && !defined(ARMA_DONT_USE_CXX11_MUTEX))
+  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
     {
     s_parent.cache_mutex.lock();
     
@@ -1274,7 +1250,7 @@ SpMat_MapMat_val<eT>::operator-=(const eT in_val)
       (*this).sub(in_val);
       }
     }
-  #elif (defined(ARMA_USE_CXX11) && !defined(ARMA_DONT_USE_CXX11_MUTEX))
+  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
     {
     s_parent.cache_mutex.lock();
     
@@ -1307,7 +1283,7 @@ SpMat_MapMat_val<eT>::operator*=(const eT in_val)
       (*this).mul(in_val);
       }
     }
-  #elif (defined(ARMA_USE_CXX11) && !defined(ARMA_DONT_USE_CXX11_MUTEX))
+  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
     {
     s_parent.cache_mutex.lock();
     
@@ -1340,7 +1316,7 @@ SpMat_MapMat_val<eT>::operator/=(const eT in_val)
       (*this).div(in_val);
       }
     }
-  #elif (defined(ARMA_USE_CXX11) && !defined(ARMA_DONT_USE_CXX11_MUTEX))
+  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
     {
     s_parent.cache_mutex.lock();
     
