@@ -29,9 +29,10 @@ class Mat : public Base< eT, Mat<eT> >
   typedef eT                                elem_type;  //!< the type of elements stored in the matrix
   typedef typename get_pod_type<eT>::result  pod_type;  //!< if eT is std::complex<T>, pod_type is T; otherwise pod_type is eT
   
-  const uword  n_rows;    //!< number of rows     (read-only)
-  const uword  n_cols;    //!< number of columns  (read-only)
-  const uword  n_elem;    //!< number of elements (read-only)
+  const uword  n_rows;    //!< number of rows               (read-only)
+  const uword  n_cols;    //!< number of columns            (read-only)
+  const uword  n_elem;    //!< number of elements           (read-only)
+  const uword  n_alloc;   //!< number of allocated elements (read-only); NOTE: n_alloc can be 0, even if n_elem > 0
   const uhword vec_state; //!< 0: matrix layout; 1: column vector layout; 2: row vector layout
   const uhword mem_state;
   
@@ -50,9 +51,9 @@ class Mat : public Base< eT, Mat<eT> >
   
   public:
   
-  static const bool is_col  = false;
-  static const bool is_row  = false;
-  static const bool is_xvec = false;
+  static constexpr bool is_col  = false;
+  static constexpr bool is_row  = false;
+  static constexpr bool is_xvec = false;
   
   inline ~Mat();
   inline  Mat();
@@ -72,7 +73,6 @@ class Mat : public Base< eT, Mat<eT> >
   inline            Mat(const std::vector<eT>& x);
   inline Mat& operator=(const std::vector<eT>& x);
   
-  #if defined(ARMA_USE_CXX11)
   inline            Mat(const std::initializer_list<eT>& list);
   inline Mat& operator=(const std::initializer_list<eT>& list);
   
@@ -81,19 +81,18 @@ class Mat : public Base< eT, Mat<eT> >
   
   inline            Mat(Mat&& m);
   inline Mat& operator=(Mat&& m);
-  #endif
   
   inline Mat(      eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols, const bool copy_aux_mem = true, const bool strict = false);
   inline Mat(const eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols);
   
-  inline Mat&  operator=(const eT val);
+  inline Mat& operator= (const eT val);
   inline Mat& operator+=(const eT val);
   inline Mat& operator-=(const eT val);
   inline Mat& operator*=(const eT val);
   inline Mat& operator/=(const eT val);
   
   inline             Mat(const Mat& m);
-  inline Mat&  operator=(const Mat& m);
+  inline Mat& operator= (const Mat& m);
   inline Mat& operator+=(const Mat& m);
   inline Mat& operator-=(const Mat& m);
   inline Mat& operator*=(const Mat& m);
@@ -101,7 +100,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline Mat& operator/=(const Mat& m);
   
   template<typename T1> inline             Mat(const BaseCube<eT,T1>& X);
-  template<typename T1> inline Mat&  operator=(const BaseCube<eT,T1>& X);
+  template<typename T1> inline Mat& operator= (const BaseCube<eT,T1>& X);
   template<typename T1> inline Mat& operator+=(const BaseCube<eT,T1>& X);
   template<typename T1> inline Mat& operator-=(const BaseCube<eT,T1>& X);
   template<typename T1> inline Mat& operator*=(const BaseCube<eT,T1>& X);
@@ -114,7 +113,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline explicit          Mat(const subview<eT>& X, const bool use_colmem);  // only to be used by the quasi_unwrap class
   
   inline             Mat(const subview<eT>& X);
-  inline Mat&  operator=(const subview<eT>& X);
+  inline Mat& operator= (const subview<eT>& X);
   inline Mat& operator+=(const subview<eT>& X);
   inline Mat& operator-=(const subview<eT>& X);
   inline Mat& operator*=(const subview<eT>& X);
@@ -129,7 +128,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline Mat(const xtrans_mat<eT,do_conj>& X);  //        xtrans_mat can only be generated by the Proxy class
   
   inline             Mat(const subview_cube<eT>& X);
-  inline Mat&  operator=(const subview_cube<eT>& X);
+  inline Mat& operator= (const subview_cube<eT>& X);
   inline Mat& operator+=(const subview_cube<eT>& X);
   inline Mat& operator-=(const subview_cube<eT>& X);
   inline Mat& operator*=(const subview_cube<eT>& X);
@@ -137,7 +136,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline Mat& operator/=(const subview_cube<eT>& X);
   
   inline             Mat(const diagview<eT>& X);
-  inline Mat&  operator=(const diagview<eT>& X);
+  inline Mat& operator= (const diagview<eT>& X);
   inline Mat& operator+=(const diagview<eT>& X);
   inline Mat& operator-=(const diagview<eT>& X);
   inline Mat& operator*=(const diagview<eT>& X);
@@ -162,15 +161,18 @@ class Mat : public Base< eT, Mat<eT> >
 
   // Operators on sparse matrices (and subviews)
   template<typename T1> inline explicit    Mat(const SpBase<eT, T1>& m);
-  template<typename T1> inline Mat&  operator=(const SpBase<eT, T1>& m);
+  template<typename T1> inline Mat& operator= (const SpBase<eT, T1>& m);
   template<typename T1> inline Mat& operator+=(const SpBase<eT, T1>& m);
   template<typename T1> inline Mat& operator-=(const SpBase<eT, T1>& m);
   template<typename T1> inline Mat& operator*=(const SpBase<eT, T1>& m);
   template<typename T1> inline Mat& operator%=(const SpBase<eT, T1>& m);
   template<typename T1> inline Mat& operator/=(const SpBase<eT, T1>& m);
   
+  inline explicit    Mat(const SpSubview<eT>& X);
+  inline Mat& operator= (const SpSubview<eT>& X);
+  
   inline explicit    Mat(const spdiagview<eT>& X);
-  inline Mat&  operator=(const spdiagview<eT>& X);
+  inline Mat& operator= (const spdiagview<eT>& X);
   inline Mat& operator+=(const spdiagview<eT>& X);
   inline Mat& operator-=(const spdiagview<eT>& X);
   inline Mat& operator*=(const spdiagview<eT>& X);
@@ -178,8 +180,8 @@ class Mat : public Base< eT, Mat<eT> >
   inline Mat& operator/=(const spdiagview<eT>& X);
   
   
-  inline mat_injector<Mat> operator<<(const eT val);
-  inline mat_injector<Mat> operator<<(const injector_end_of_row<>& x);
+  arma_cold inline mat_injector<Mat> operator<<(const eT val);
+  arma_cold inline mat_injector<Mat> operator<<(const injector_end_of_row<>& x);
   
   
   arma_inline       subview_row<eT> row(const uword row_num);
@@ -275,13 +277,11 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1> inline const subview_each2< Mat<eT>, 0, T1 > each_col(const Base<uword, T1>& indices) const;
   template<typename T1> inline const subview_each2< Mat<eT>, 1, T1 > each_row(const Base<uword, T1>& indices) const;
   
-  #if defined(ARMA_USE_CXX11)
   inline const Mat& each_col(const std::function< void(      Col<eT>&) >& F);
   inline const Mat& each_col(const std::function< void(const Col<eT>&) >& F) const;
   
   inline const Mat& each_row(const std::function< void(      Row<eT>&) >& F);
   inline const Mat& each_row(const std::function< void(const Row<eT>&) >& F) const;
-  #endif
   
   
   arma_inline       diagview<eT> diag(const sword in_id = 0);
@@ -308,7 +308,7 @@ class Mat : public Base< eT, Mat<eT> >
   
   
   template<typename T1, typename gen_type> inline             Mat(const Gen<T1, gen_type>& X);
-  template<typename T1, typename gen_type> inline Mat&  operator=(const Gen<T1, gen_type>& X);
+  template<typename T1, typename gen_type> inline Mat& operator= (const Gen<T1, gen_type>& X);
   template<typename T1, typename gen_type> inline Mat& operator+=(const Gen<T1, gen_type>& X);
   template<typename T1, typename gen_type> inline Mat& operator-=(const Gen<T1, gen_type>& X);
   template<typename T1, typename gen_type> inline Mat& operator*=(const Gen<T1, gen_type>& X);
@@ -316,7 +316,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename gen_type> inline Mat& operator/=(const Gen<T1, gen_type>& X);
   
   template<typename T1, typename op_type> inline             Mat(const Op<T1, op_type>& X);
-  template<typename T1, typename op_type> inline Mat&  operator=(const Op<T1, op_type>& X);
+  template<typename T1, typename op_type> inline Mat& operator= (const Op<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator+=(const Op<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator-=(const Op<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator*=(const Op<T1, op_type>& X);
@@ -324,7 +324,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename op_type> inline Mat& operator/=(const Op<T1, op_type>& X);
   
   template<typename T1, typename eop_type> inline             Mat(const eOp<T1, eop_type>& X);
-  template<typename T1, typename eop_type> inline Mat&  operator=(const eOp<T1, eop_type>& X);
+  template<typename T1, typename eop_type> inline Mat& operator= (const eOp<T1, eop_type>& X);
   template<typename T1, typename eop_type> inline Mat& operator+=(const eOp<T1, eop_type>& X);
   template<typename T1, typename eop_type> inline Mat& operator-=(const eOp<T1, eop_type>& X);
   template<typename T1, typename eop_type> inline Mat& operator*=(const eOp<T1, eop_type>& X);
@@ -332,7 +332,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename eop_type> inline Mat& operator/=(const eOp<T1, eop_type>& X);
   
   template<typename T1, typename op_type> inline             Mat(const mtOp<eT, T1, op_type>& X);
-  template<typename T1, typename op_type> inline Mat&  operator=(const mtOp<eT, T1, op_type>& X);
+  template<typename T1, typename op_type> inline Mat& operator= (const mtOp<eT, T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator+=(const mtOp<eT, T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator-=(const mtOp<eT, T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator*=(const mtOp<eT, T1, op_type>& X);
@@ -340,7 +340,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename op_type> inline Mat& operator/=(const mtOp<eT, T1, op_type>& X);
 
   template<typename T1, typename op_type> inline             Mat(const CubeToMatOp<T1, op_type>& X);
-  template<typename T1, typename op_type> inline Mat&  operator=(const CubeToMatOp<T1, op_type>& X);
+  template<typename T1, typename op_type> inline Mat& operator= (const CubeToMatOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator+=(const CubeToMatOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator-=(const CubeToMatOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator*=(const CubeToMatOp<T1, op_type>& X);
@@ -348,7 +348,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename op_type> inline Mat& operator/=(const CubeToMatOp<T1, op_type>& X);
   
   template<typename T1, typename op_type> inline             Mat(const SpToDOp<T1, op_type>& X);
-  template<typename T1, typename op_type> inline Mat&  operator=(const SpToDOp<T1, op_type>& X);
+  template<typename T1, typename op_type> inline Mat& operator= (const SpToDOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator+=(const SpToDOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator-=(const SpToDOp<T1, op_type>& X);
   template<typename T1, typename op_type> inline Mat& operator*=(const SpToDOp<T1, op_type>& X);
@@ -356,7 +356,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename op_type> inline Mat& operator/=(const SpToDOp<T1, op_type>& X);
   
   template<typename T1, typename T2, typename glue_type> inline             Mat(const Glue<T1, T2, glue_type>& X);
-  template<typename T1, typename T2, typename glue_type> inline Mat&  operator=(const Glue<T1, T2, glue_type>& X);
+  template<typename T1, typename T2, typename glue_type> inline Mat& operator= (const Glue<T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator+=(const Glue<T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator-=(const Glue<T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator*=(const Glue<T1, T2, glue_type>& X);
@@ -367,7 +367,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename T2>                     inline Mat& operator-=(const Glue<T1, T2, glue_times>& X);
   
   template<typename T1, typename T2, typename eglue_type> inline             Mat(const eGlue<T1, T2, eglue_type>& X);
-  template<typename T1, typename T2, typename eglue_type> inline Mat&  operator=(const eGlue<T1, T2, eglue_type>& X);
+  template<typename T1, typename T2, typename eglue_type> inline Mat& operator= (const eGlue<T1, T2, eglue_type>& X);
   template<typename T1, typename T2, typename eglue_type> inline Mat& operator+=(const eGlue<T1, T2, eglue_type>& X);
   template<typename T1, typename T2, typename eglue_type> inline Mat& operator-=(const eGlue<T1, T2, eglue_type>& X);
   template<typename T1, typename T2, typename eglue_type> inline Mat& operator*=(const eGlue<T1, T2, eglue_type>& X);
@@ -375,7 +375,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename T2, typename eglue_type> inline Mat& operator/=(const eGlue<T1, T2, eglue_type>& X);
   
   template<typename T1, typename T2, typename glue_type> inline             Mat(const mtGlue<eT, T1, T2, glue_type>& X);
-  template<typename T1, typename T2, typename glue_type> inline Mat&  operator=(const mtGlue<eT, T1, T2, glue_type>& X);
+  template<typename T1, typename T2, typename glue_type> inline Mat& operator= (const mtGlue<eT, T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator+=(const mtGlue<eT, T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator-=(const mtGlue<eT, T1, T2, glue_type>& X);
   template<typename T1, typename T2, typename glue_type> inline Mat& operator*=(const mtGlue<eT, T1, T2, glue_type>& X);
@@ -520,18 +520,22 @@ class Mat : public Base< eT, Mat<eT> >
   
   inline arma_cold bool save(const std::string   name, const file_type type = arma_binary, const bool print_status = true) const;
   inline arma_cold bool save(const hdf5_name&    spec, const file_type type = hdf5_binary, const bool print_status = true) const;
+  inline arma_cold bool save(const  csv_name&    spec, const file_type type =   csv_ascii, const bool print_status = true) const;
   inline arma_cold bool save(      std::ostream& os,   const file_type type = arma_binary, const bool print_status = true) const;
   
   inline arma_cold bool load(const std::string   name, const file_type type = auto_detect, const bool print_status = true);
   inline arma_cold bool load(const hdf5_name&    spec, const file_type type = hdf5_binary, const bool print_status = true);
+  inline arma_cold bool load(const  csv_name&    spec, const file_type type =   csv_ascii, const bool print_status = true);
   inline arma_cold bool load(      std::istream& is,   const file_type type = auto_detect, const bool print_status = true);
   
   inline arma_cold bool quiet_save(const std::string   name, const file_type type = arma_binary) const;
   inline arma_cold bool quiet_save(const hdf5_name&    spec, const file_type type = hdf5_binary) const;
+  inline arma_cold bool quiet_save(const  csv_name&    spec, const file_type type =   csv_ascii) const;
   inline arma_cold bool quiet_save(      std::ostream& os,   const file_type type = arma_binary) const;
   
   inline arma_cold bool quiet_load(const std::string   name, const file_type type = auto_detect);
   inline arma_cold bool quiet_load(const hdf5_name&    spec, const file_type type = hdf5_binary);
+  inline arma_cold bool quiet_load(const  csv_name&    spec, const file_type type =   csv_ascii);
   inline arma_cold bool quiet_load(      std::istream& is,   const file_type type = auto_detect);
   
   
@@ -747,10 +751,8 @@ class Mat : public Base< eT, Mat<eT> >
   
   inline arma_cold void init(const std::string& text);
   
-  #if defined(ARMA_USE_CXX11)
-    inline void init(const std::initializer_list<eT>& list);
-    inline void init(const std::initializer_list< std::initializer_list<eT> >& list);
-  #endif
+  inline void init(const std::initializer_list<eT>& list);
+  inline void init(const std::initializer_list< std::initializer_list<eT> >& list);
   
   template<typename T1, typename T2>
   inline void init(const Base<pod_type,T1>& A, const Base<pod_type,T2>& B);
@@ -789,8 +791,8 @@ class Mat<eT>::fixed : public Mat<eT>
   {
   private:
   
-  static const uword fixed_n_elem = fixed_n_rows * fixed_n_cols;
-  static const bool  use_extra    = (fixed_n_elem > arma_config::mat_prealloc);
+  static constexpr uword fixed_n_elem = fixed_n_rows * fixed_n_cols;
+  static constexpr bool  use_extra    = (fixed_n_elem > arma_config::mat_prealloc);
   
   arma_align_mem eT mem_local_extra[ (use_extra) ? fixed_n_elem : 1 ];
   
@@ -802,9 +804,9 @@ class Mat<eT>::fixed : public Mat<eT>
   typedef eT                                elem_type;
   typedef typename get_pod_type<eT>::result pod_type;
   
-  static const bool is_col  = (fixed_n_cols == 1);
-  static const bool is_row  = (fixed_n_rows == 1);
-  static const bool is_xvec = false;
+  static constexpr bool is_col  = (fixed_n_cols == 1);
+  static constexpr bool is_row  = (fixed_n_rows == 1);
+  static constexpr bool is_xvec = false;
   
   static const uword n_rows;  // value provided below the class definition
   static const uword n_cols;  // value provided below the class definition
@@ -825,13 +827,11 @@ class Mat<eT>::fixed : public Mat<eT>
   using Mat<eT>::operator=;
   using Mat<eT>::operator();
   
-  #if defined(ARMA_USE_CXX11)
-    inline          fixed(const std::initializer_list<eT>& list);
-    inline Mat& operator=(const std::initializer_list<eT>& list);
-    
-    inline          fixed(const std::initializer_list< std::initializer_list<eT> >& list);
-    inline Mat& operator=(const std::initializer_list< std::initializer_list<eT> >& list);
-  #endif
+  inline          fixed(const std::initializer_list<eT>& list);
+  inline Mat& operator=(const std::initializer_list<eT>& list);
+  
+  inline          fixed(const std::initializer_list< std::initializer_list<eT> >& list);
+  inline Mat& operator=(const std::initializer_list< std::initializer_list<eT> >& list);
   
   arma_inline Mat& operator=(const fixed<fixed_n_rows, fixed_n_cols>& X);
   
