@@ -22,93 +22,93 @@
 struct arma_config
   {
   #if defined(ARMA_MAT_PREALLOC)
-    static const uword mat_prealloc = (sword(ARMA_MAT_PREALLOC) > 0) ? uword(ARMA_MAT_PREALLOC) : 1;
+    static constexpr uword mat_prealloc = (sword(ARMA_MAT_PREALLOC) > 0) ? uword(ARMA_MAT_PREALLOC) : 1;
   #else
-    static const uword mat_prealloc = 16;
+    static constexpr uword mat_prealloc = 16;
   #endif
   
   
   #if defined(ARMA_OPENMP_THRESHOLD)
-    static const uword mp_threshold = (sword(ARMA_OPENMP_THRESHOLD) > 0) ? uword(ARMA_OPENMP_THRESHOLD) : 240;
+    static constexpr uword mp_threshold = (sword(ARMA_OPENMP_THRESHOLD) > 0) ? uword(ARMA_OPENMP_THRESHOLD) : 240;
   #else
-    static const uword mp_threshold = 240;
+    static constexpr uword mp_threshold = 240;
   #endif
   
   
   #if defined(ARMA_OPENMP_THREADS)
-    static const uword mp_threads = (sword(ARMA_OPENMP_THREADS) > 0) ? uword(ARMA_OPENMP_THREADS) : 10;
+    static constexpr uword mp_threads = (sword(ARMA_OPENMP_THREADS) > 0) ? uword(ARMA_OPENMP_THREADS) : 10;
   #else
-    static const uword mp_threads = 10;
+    static constexpr uword mp_threads = 10;
   #endif
   
   
   #if defined(ARMA_USE_ATLAS)
-    static const bool atlas = true;
+    static constexpr bool atlas = true;
   #else
-    static const bool atlas = false;
+    static constexpr bool atlas = false;
   #endif
   
   
   #if defined(ARMA_USE_LAPACK)
-    static const bool lapack = true;
+    static constexpr bool lapack = true;
   #else
-    static const bool lapack = false;
+    static constexpr bool lapack = false;
   #endif
   
   
   #if defined(ARMA_USE_BLAS)
-    static const bool blas = true;
+    static constexpr bool blas = true;
   #else
-    static const bool blas = false;
+    static constexpr bool blas = false;
   #endif
   
   
   #if defined(ARMA_USE_NEWARP)
-    static const bool newarp = true;
+    static constexpr bool newarp = true;
   #else
-    static const bool newarp = false;
+    static constexpr bool newarp = false;
   #endif
   
   
   #if defined(ARMA_USE_ARPACK)
-    static const bool arpack = true;
+    static constexpr bool arpack = true;
   #else
-    static const bool arpack = false;
+    static constexpr bool arpack = false;
   #endif
   
   
   #if defined(ARMA_USE_SUPERLU)
-    static const bool superlu = true;
+    static constexpr bool superlu = true;
   #else
-    static const bool superlu = false;
+    static constexpr bool superlu = false;
   #endif
   
   
   #if defined(ARMA_USE_HDF5)
-    static const bool hdf5 = true;
+    static constexpr bool hdf5 = true;
   #else
-    static const bool hdf5 = false;
+    static constexpr bool hdf5 = false;
   #endif
   
   
   #if defined(ARMA_NO_DEBUG)
-    static const bool debug = false;
+    static constexpr bool debug = false;
   #else
-    static const bool debug = true;
+    static constexpr bool debug = true;
   #endif
   
   
   #if defined(ARMA_EXTRA_DEBUG)
-    static const bool extra_debug = true;
+    static constexpr bool extra_debug = true;
   #else
-    static const bool extra_debug = false;
+    static constexpr bool extra_debug = false;
   #endif
   
   
   #if defined(ARMA_GOOD_COMPILER)
-    static const bool good_comp = true;
+    static constexpr bool good_comp = true;
   #else
-    static const bool good_comp = false;
+    static constexpr bool good_comp = false;
   #endif
   
   
@@ -122,37 +122,58 @@ struct arma_config
       || defined(ARMA_EXTRA_SPCOL_PROTO) || defined(ARMA_EXTRA_SPCOL_MEAT) \
       || defined(ARMA_EXTRA_SPROW_PROTO) || defined(ARMA_EXTRA_SPROW_MEAT) \
       )
-    static const bool extra_code = true;
+    static constexpr bool extra_code = true;
   #else
-    static const bool extra_code = false;
+    static constexpr bool extra_code = false;
   #endif
   
   
-  #if defined(ARMA_USE_CXX11)
-    static const bool cxx11 = true;
+  #if defined(ARMA_HAVE_CXX14)
+    static constexpr bool cxx14 = true;
   #else
-    static const bool cxx11 = false;
+    static constexpr bool cxx14 = false;
+  #endif
+  
+  
+  #if defined(ARMA_HAVE_CXX17)
+    static constexpr bool cxx17 = true;
+  #else
+    static constexpr bool cxx17 = false;
+  #endif
+  
+  
+  #if (!defined(ARMA_DONT_USE_STD_MUTEX))
+    static constexpr bool std_mutex = true;
+  #else
+    static constexpr bool std_mutex = false;
   #endif
   
   
   #if (defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200112L))
-    static const bool posix = true;
+    static constexpr bool posix = true;
   #else
-    static const bool posix = false;
+    static constexpr bool posix = false;
   #endif
   
   
   #if defined(ARMA_USE_WRAPPER)
-    static const bool wrapper = true;
+    static constexpr bool wrapper = true;
   #else
-    static const bool wrapper = false;
+    static constexpr bool wrapper = false;
   #endif
   
   
   #if defined(ARMA_USE_OPENMP)
-    static const bool openmp = true;
+    static constexpr bool openmp = true;
   #else
-    static const bool openmp = false;
+    static constexpr bool openmp = false;
+  #endif
+  
+  
+  #if defined(ARMA_USE_FORTRAN_HIDDEN_ARGS)
+    static constexpr bool hidden_args = true;
+  #else
+    static constexpr bool hidden_args = false;
   #endif
   };
 
