@@ -163,7 +163,7 @@
 
 
 
-#if (defined(ARMA_USE_OPENMP) && defined(ARMA_USE_CXX11))
+#if defined(ARMA_USE_OPENMP)
   
   #define arma_applier_1_mp(operatorA) \
     {\
@@ -254,7 +254,7 @@ eop_core<eop_type>::apply(outT& out, const eOp<T1, eop_type>& x)
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(Proxy<T1>::use_at == false)
     {
@@ -332,7 +332,7 @@ eop_core<eop_type>::apply_inplace_plus(Mat<typename T1::elem_type>& out, const e
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(Proxy<T1>::use_at == false)
     {
@@ -407,7 +407,7 @@ eop_core<eop_type>::apply_inplace_minus(Mat<typename T1::elem_type>& out, const
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(Proxy<T1>::use_at == false)
     {
@@ -482,7 +482,7 @@ eop_core<eop_type>::apply_inplace_schur(Mat<typename T1::elem_type>& out, const
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(Proxy<T1>::use_at == false)
     {
@@ -557,7 +557,7 @@ eop_core<eop_type>::apply_inplace_div(Mat<typename T1::elem_type>& out, const eO
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOp<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(Proxy<T1>::use_at == false)
     {
@@ -635,7 +635,7 @@ eop_core<eop_type>::apply(Cube<typename T1::elem_type>& out, const eOpCube<T1, e
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(ProxyCube<T1>::use_at == false)
     {
@@ -715,7 +715,7 @@ eop_core<eop_type>::apply_inplace_plus(Cube<typename T1::elem_type>& out, const
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(ProxyCube<T1>::use_at == false)
     {
@@ -791,7 +791,7 @@ eop_core<eop_type>::apply_inplace_minus(Cube<typename T1::elem_type>& out, const
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(ProxyCube<T1>::use_at == false)
     {
@@ -867,7 +867,7 @@ eop_core<eop_type>::apply_inplace_schur(Cube<typename T1::elem_type>& out, const
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(ProxyCube<T1>::use_at == false)
     {
@@ -943,7 +943,7 @@ eop_core<eop_type>::apply_inplace_div(Cube<typename T1::elem_type>& out, const e
   const eT  k       = x.aux;
         eT* out_mem = out.memptr();
   
-  const bool use_mp = (arma_config::cxx11 && arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
+  const bool use_mp = (arma_config::openmp) && (eOpCube<T1, eop_type>::use_mp || (is_same_type<eop_type, eop_pow>::value && (is_cx<eT>::yes || x.aux != eT(2))));
   
   if(ProxyCube<T1>::use_at == false)
     {
@@ -1056,6 +1056,9 @@ eop_core<eop_log10            >::process(const eT val, const eT  ) { return eop_
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_trunc_log        >::process(const eT val, const eT  ) { return    arma::trunc_log(val);  }
 
+template<> template<typename eT> arma_hot arma_inline eT
+eop_core<eop_log1p            >::process(const eT val, const eT  ) { return eop_aux::log1p(val);      }
+
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_exp              >::process(const eT val, const eT  ) { return eop_aux::exp(val);        }
 
@@ -1068,6 +1071,9 @@ eop_core<eop_exp10            >::process(const eT val, const eT  ) { return eop_
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_trunc_exp        >::process(const eT val, const eT  ) { return    arma::trunc_exp(val);  }
 
+template<> template<typename eT> arma_hot arma_inline eT
+eop_core<eop_expm1            >::process(const eT val, const eT  ) { return eop_aux::expm1(val);      }
+
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_cos              >::process(const eT val, const eT  ) { return eop_aux::cos(val);        }
 
@@ -1104,6 +1110,9 @@ eop_core<eop_asinh            >::process(const eT val, const eT  ) { return eop_
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_atanh            >::process(const eT val, const eT  ) { return eop_aux::atanh(val);      }
 
+template<> template<typename eT> arma_hot arma_inline eT
+eop_core<eop_sinc             >::process(const eT val, const eT  ) { return arma_sinc(val);           }
+
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_eps              >::process(const eT val, const eT  ) { return eop_aux::direct_eps(val); }
 
@@ -1132,7 +1141,7 @@ template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_trunc            >::process(const eT val, const eT  ) { return eop_aux::trunc(val);      }
 
 template<> template<typename eT> arma_hot arma_inline eT
-eop_core<eop_sign             >::process(const eT val, const eT  ) { return eop_aux::sign(val);       }
+eop_core<eop_sign             >::process(const eT val, const eT  ) { return arma_sign(val);           }
 
 template<> template<typename eT> arma_hot arma_inline eT
 eop_core<eop_erf              >::process(const eT val, const eT  ) { return eop_aux::erf(val);        }
