@@ -57,7 +57,7 @@ template<typename obj_type>
 arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
-randu(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<obj_type>::result* junk2 = 0)
+randu(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<obj_type>::result* junk2 = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk1);
@@ -104,7 +104,7 @@ template<typename obj_type>
 arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
-randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
+randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
@@ -128,7 +128,7 @@ template<typename obj_type>
 arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
-randu(const SizeMat& s, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
+randu(const SizeMat& s, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
@@ -166,7 +166,7 @@ template<typename cube_type>
 arma_warn_unused
 arma_inline
 const GenCube<typename cube_type::elem_type, gen_randu>
-randu(const uword n_rows, const uword n_cols, const uword n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
+randu(const uword n_rows, const uword n_cols, const uword n_slices, const typename arma_Cube_only<cube_type>::result* junk = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
@@ -180,7 +180,7 @@ template<typename cube_type>
 arma_warn_unused
 arma_inline
 const GenCube<typename cube_type::elem_type, gen_randu>
-randu(const SizeCube& s, const typename arma_Cube_only<cube_type>::result* junk = 0)
+randu(const SizeCube& s, const typename arma_Cube_only<cube_type>::result* junk = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
