@@ -26,8 +26,8 @@ const Op<T1, op_strans>
 strans
   (
   const T1& X,
-  const typename enable_if< is_arma_type<T1>::value == true >::result* junk1 = 0,
-  const typename arma_cx_only<typename T1::elem_type>::result*         junk2 = 0
+  const typename enable_if< is_arma_type<T1>::value == true >::result* junk1 = nullptr,
+  const typename arma_cx_only<typename T1::elem_type>::result*         junk2 = nullptr
   )
   {
   arma_extra_debug_sigprint();
@@ -48,8 +48,8 @@ const Op<T1, op_htrans>
 strans
   (
   const T1& X,
-  const typename enable_if< is_arma_type<T1>::value == true >::result* junk1 = 0,
-  const typename arma_not_cx<typename T1::elem_type>::result*          junk2 = 0
+  const typename enable_if< is_arma_type<T1>::value == true >::result* junk1 = nullptr,
+  const typename arma_not_cx<typename T1::elem_type>::result*          junk2 = nullptr
   )
   {
   arma_extra_debug_sigprint();
@@ -72,8 +72,8 @@ const SpOp<T1, spop_strans>
 strans
   (
   const T1& X,
-  const typename enable_if< is_arma_sparse_type<T1>::value == true >::result* junk1 = 0,
-  const typename arma_cx_only<typename T1::elem_type>::result*                junk2 = 0
+  const typename enable_if< is_arma_sparse_type<T1>::value == true >::result* junk1 = nullptr,
+  const typename arma_cx_only<typename T1::elem_type>::result*                junk2 = nullptr
   )
   {
   arma_extra_debug_sigprint();
@@ -92,8 +92,8 @@ const SpOp<T1, spop_htrans>
 strans
   (
   const T1& X,
-  const typename enable_if< is_arma_sparse_type<T1>::value == true >::result* junk1 = 0,
-  const typename arma_not_cx<typename T1::elem_type>::result*                 junk2 = 0
+  const typename enable_if< is_arma_sparse_type<T1>::value == true >::result* junk1 = nullptr,
+  const typename arma_not_cx<typename T1::elem_type>::result*                 junk2 = nullptr
   )
   {
   arma_extra_debug_sigprint();
