@@ -62,10 +62,7 @@ op_expmat::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1
     
     const uword N = (std::min)(out.n_rows, out.n_cols);
     
-    for(uword i=0; i<N; ++i)
-      {
-      out.at(i,i) = std::exp( out.at(i,i) );
-      }
+    for(uword i=0; i<N; ++i)  { out.at(i,i) = std::exp( out.at(i,i) ); }
     }
   else
     {
@@ -73,6 +70,46 @@ op_expmat::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1
     
     arma_debug_check( (A.is_square() == false), "expmat(): given matrix must be square sized" );
     
+    if(A.is_diagmat())
+      {
+      const uword N = (std::min)(A.n_rows, A.n_cols);
+      
+      out.zeros(N,N);
+      
+      for(uword i=0; i<N; ++i)  { out.at(i,i) = std::exp( A.at(i,i) ); }
+      
+      return true;
+      }
+    
+    #if defined(ARMA_OPTIMISE_SYMPD)
+      const bool try_sympd = sympd_helper::guess_sympd_anysize(A);
+    #else
+      const bool try_sympd = false;
+    #endif
+    
+    if(try_sympd)
+      {
+      // if matrix A is sympd, all its eigenvalues are positive
+      
+      Col< T> eigval;
+      Mat<eT> eigvec;
+      
+      const bool eig_status = eig_sym_helper(eigval, eigvec, A, 'd', "expmat()");
+      
+      if(eig_status)
+        {
+        eigval = exp(eigval);
+        
+        out = eigvec * diagmat(eigval) * eigvec.t();
+        
+        return true;
+        }
+      
+      arma_extra_debug_print("warning: sympd optimisation failed");
+      
+      // fallthrough if eigen decomposition failed
+      }
+    
     const T norm_val = arma::norm(A, "inf");
     
     const double log2_val = (norm_val > T(0)) ? double(eop_aux::log2(norm_val)) : double(0);
@@ -109,7 +146,7 @@ op_expmat::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1
     
     if( (D.is_finite() == false) || (E.is_finite() == false) )  { return false; }
     
-    const bool status = solve(out, D, E);
+    const bool status = solve(out, D, E, solve_opts::no_approx);
     
     if(status == false)  { return false; }
     
