@@ -25,7 +25,7 @@ sp_auxlib::interpret_form_str(const char* form_str)
   arma_extra_debug_sigprint();
   
   // the order of the 3 if statements below is important
-  if( form_str    == NULL    )  { return form_none; }
+  if( form_str    == nullptr )  { return form_none; }
   if( form_str[0] == char(0) )  { return form_none; }
   if( form_str[1] == char(0) )  { return form_none; }
   
@@ -57,7 +57,7 @@ sp_auxlib::interpret_form_str(const char* form_str)
 template<typename eT, typename T1>
 inline
 bool
-sp_auxlib::eigs_sym(Col<eT>& eigval, Mat<eT>& eigvec, const SpBase<eT, T1>& X, const uword n_eigvals, const char* form_str, const eT default_tol)
+sp_auxlib::eigs_sym(Col<eT>& eigval, Mat<eT>& eigvec, const SpBase<eT, T1>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
@@ -71,19 +71,19 @@ sp_auxlib::eigs_sym(Col<eT>& eigval, Mat<eT>& eigvec, const SpBase<eT, T1>& X, c
   
   #if   defined(ARMA_USE_NEWARP)
     {
-    return sp_auxlib::eigs_sym_newarp(eigval, eigvec, U.M, n_eigvals, form_str, default_tol);
+    return sp_auxlib::eigs_sym_newarp(eigval, eigvec, U.M, n_eigvals, form_val, opts);
     }
   #elif defined(ARMA_USE_ARPACK)
     {
-    return sp_auxlib::eigs_sym_arpack(eigval, eigvec, U.M, n_eigvals, form_str, default_tol);
+    return sp_auxlib::eigs_sym_arpack(eigval, eigvec, U.M, n_eigvals, form_val, opts);
     }
   #else
     {
     arma_ignore(eigval);
     arma_ignore(eigvec);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     arma_stop_logic_error("eigs_sym(): use of NEWARP or ARPACK must be enabled");
     return false;
@@ -96,14 +96,12 @@ sp_auxlib::eigs_sym(Col<eT>& eigval, Mat<eT>& eigvec, const SpBase<eT, T1>& X, c
 template<typename eT>
 inline
 bool
-sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X, const uword n_eigvals, const char* form_str, const eT default_tol)
+sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
   #if defined(ARMA_USE_NEWARP)
     {
-    const form_type form_val = sp_auxlib::interpret_form_str(form_str);
-    
     arma_debug_check( (form_val != form_lm) && (form_val != form_sm) && (form_val != form_la) && (form_val != form_sa), "eigs_sym(): unknown form specified" );
     
     const newarp::SparseGenMatProd<eT> op(X);
@@ -121,12 +119,39 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
       }
     
     uword n   = op.n_rows;
-    uword ncv = n_eigvals + 2 + 1;
     
-    if(ncv < (2 * n_eigvals + 1)) { ncv = 2 * n_eigvals + 1; }
-    if(ncv > n)                   { ncv = n; }
+    // Use max(2*k+1, 20) as default subspace dimension for the sym case; MATLAB uses max(2*k, 20), but we need to be backward-compatible.
+    uword ncv_default = uword( ((2*n_eigvals+1)>(20)) ? (2*n_eigvals+1) : (20) );
     
-    eT tol = (std::max)(default_tol, std::numeric_limits<eT>::epsilon());
+    // Use opts.subdim only if it's within the limits, otherwise cap it.
+    uword ncv = ncv_default;
+    
+    if(opts.subdim != 0)
+      {
+      if(opts.subdim < (n_eigvals + 1))
+        {
+        arma_debug_warn("eigs_sym(): opts.subdim must be greater than k; using k+1 instead of ", opts.subdim);
+        ncv = uword(n_eigvals + 1);
+        }
+      else
+      if(opts.subdim > n)
+        {
+        arma_debug_warn("eigs_sym(): opts.subdim cannot be greater than n_rows; using n_rows instead of ", opts.subdim);
+        ncv = n;
+        }
+      else
+        {
+        ncv = uword(opts.subdim);
+        }
+      }
+    
+    // Re-check that we are within the limits
+    if(ncv < (n_eigvals + 1)) { ncv = (n_eigvals + 1); }
+    if(ncv > n              ) { ncv = n;               }
+    
+    eT tol = (std::max)(eT(opts.tol), std::numeric_limits<eT>::epsilon());
+    
+    uword maxiter = uword(opts.maxiter);
     
     // eigval.set_size(n_eigvals);
     // eigvec.set_size(n, n_eigvals);
@@ -141,7 +166,7 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
         {
         newarp::SymEigsSolver< eT, newarp::EigsSelect::LARGEST_MAGN, newarp::SparseGenMatProd<eT> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -150,7 +175,7 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
         {
         newarp::SymEigsSolver< eT, newarp::EigsSelect::SMALLEST_MAGN, newarp::SparseGenMatProd<eT> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -159,7 +184,7 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
         {
         newarp::SymEigsSolver< eT, newarp::EigsSelect::LARGEST_ALGE, newarp::SparseGenMatProd<eT> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -168,7 +193,7 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
         {
         newarp::SymEigsSolver< eT, newarp::EigsSelect::SMALLEST_ALGE, newarp::SparseGenMatProd<eT> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -191,8 +216,8 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
     arma_ignore(eigvec);
     arma_ignore(X);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     return false;
     }
@@ -204,14 +229,12 @@ sp_auxlib::eigs_sym_newarp(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
 template<typename eT>
 inline
 bool
-sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X, const uword n_eigvals, const char* form_str, const eT default_tol)
+sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
   #if defined(ARMA_USE_ARPACK)
     {
-    const form_type form_val = sp_auxlib::interpret_form_str(form_str);
-    
     arma_debug_check( (form_val != form_lm) && (form_val != form_sm) && (form_val != form_la) && (form_val != form_sa), "eigs_sym(): unknown form specified" );
     
     char  which_sm[3] = "SM";
@@ -219,6 +242,7 @@ sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
     char  which_sa[3] = "SA";
     char  which_la[3] = "LA";
     char* which;
+    
     switch (form_val)
       {
       case form_sm:  which = which_sm;  break;
@@ -245,22 +269,49 @@ sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
       }
     
     // Set up variables that get used for neupd().
-    blas_int n, ncv, ldv, lworkl, info;
-    eT tol = default_tol;
+    blas_int n, ncv, ncv_default, ldv, lworkl, info, maxiter;
+    
+    eT tol  = eT(opts.tol);
+    maxiter = blas_int(opts.maxiter);
+    
     podarray<eT> resid, v, workd, workl;
     podarray<blas_int> iparam, ipntr;
     podarray<eT> rwork; // Not used in this case.
     
-    run_aupd(n_eigvals, which, X, true /* sym, not gen */, n, tol, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
+    n = blas_int(X.n_rows); // The size of the matrix.
     
-    if(info != 0)
+    // Use max(2*k+1, 20) as default subspace dimension for the sym case; MATLAB uses max(2*k, 20), but we need to be backward-compatible.
+    ncv_default = blas_int( ((2*n_eigvals+1)>(20)) ? (2*n_eigvals+1) : (20) );
+    
+    // Use opts.subdim only if it's within the limits
+    ncv = ncv_default;
+    
+    if(opts.subdim != 0)
       {
-      return false;
+      if(opts.subdim < (n_eigvals + 1))
+        {
+        arma_debug_warn("eigs_sym(): opts.subdim must be greater than k; using k+1 instead of ", opts.subdim);
+        ncv = blas_int(n_eigvals + 1);
+        }
+      else
+      if(blas_int(opts.subdim) > n)
+        {
+        arma_debug_warn("eigs_sym(): opts.subdim cannot be greater than n_rows; using n_rows instead of ", opts.subdim);
+        ncv = n;
+        }
+      else
+        {
+        ncv = blas_int(opts.subdim);
+        }
       }
     
+    run_aupd(n_eigvals, which, X, true /* sym, not gen */, n, tol, maxiter, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
+    
+    if(info != 0)  { return false; }
+    
     // The process has converged, and now we need to recover the actual eigenvectors using seupd()
     blas_int rvec = 1; // .TRUE
-    blas_int nev  = n_eigvals;
+    blas_int nev  = blas_int(n_eigvals);
     
     char howmny = 'A';
     char bmat   = 'I'; // We are considering the standard eigenvalue problem.
@@ -272,7 +323,9 @@ sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
     eigval.zeros(n_eigvals);
     eigvec.zeros(n, n_eigvals);
     
-    arpack::seupd(&rvec, &howmny, select.memptr(), eigval.memptr(), eigvec.memptr(), &ldz, (eT*) NULL, &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, &info);
+    eT sigma = eT(0);
+    
+    arpack::seupd(&rvec, &howmny, select.memptr(), eigval.memptr(), eigvec.memptr(), &ldz, (eT*) &sigma, &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, &info);
     
     // Check for errors.
     if(info != 0)
@@ -289,8 +342,8 @@ sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
     arma_ignore(eigvec);
     arma_ignore(X);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     return false;
     }
@@ -303,21 +356,21 @@ sp_auxlib::eigs_sym_arpack(Col<eT>& eigval, Mat<eT>& eigvec, const SpMat<eT>& X,
 template<typename T, typename T1>
 inline
 bool
-sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpBase<T, T1>& X, const uword n_eigvals, const char* form_str, const T default_tol)
+sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpBase<T, T1>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
-  
+
   #if defined(ARMA_USE_NEWARP)
     {
     const unwrap_spmat<T1> U(X.get_ref());
-  
-    return sp_auxlib::eigs_gen_newarp(eigval, eigvec, U.M, n_eigvals, form_str, default_tol);
+    
+    return sp_auxlib::eigs_gen_newarp(eigval, eigvec, U.M, n_eigvals, form_val, opts);
     }
   #elif defined(ARMA_USE_ARPACK)
     {
     const unwrap_spmat<T1> U(X.get_ref());
-  
-    return sp_auxlib::eigs_gen_arpack(eigval, eigvec, U.M, n_eigvals, form_str, default_tol);
+    
+    return sp_auxlib::eigs_gen_arpack(eigval, eigvec, U.M, n_eigvals, form_val, opts);
     }
   #else
     {
@@ -325,8 +378,8 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     arma_ignore(eigvec);
     arma_ignore(X);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     arma_stop_logic_error("eigs_gen(): use of NEWARP or ARPACK must be enabled");
     return false;
@@ -339,14 +392,12 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
 template<typename T>
 inline
 bool
-sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpMat<T>& X, const uword n_eigvals, const char* form_str, const T default_tol)
+sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpMat<T>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
   #if defined(ARMA_USE_NEWARP)
     {
-    const form_type form_val = sp_auxlib::interpret_form_str(form_str);
-    
     arma_debug_check( (form_val == form_none), "eigs_gen(): unknown form specified" );
     
     const newarp::SparseGenMatProd<T> op(X);
@@ -364,12 +415,39 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
       }
     
     uword n   = op.n_rows;
-    uword ncv = n_eigvals + 2 + 1;
     
-    if(ncv < (2 * n_eigvals + 1)) { ncv = 2 * n_eigvals + 1; }
-    if(ncv > n)                   { ncv = n; }
+    // Use max(2*k+1, 20) as default subspace dimension for the gen case; same as MATLAB.
+    uword ncv_default = uword( ((2*n_eigvals+1)>(20)) ? (2*n_eigvals+1) : (20) );
     
-    T tol = (std::max)(default_tol, std::numeric_limits<T>::epsilon());
+    // Use opts.subdim only if it's within the limits
+    uword ncv = ncv_default;
+    
+    if(opts.subdim != 0)
+      {
+      if(opts.subdim < (n_eigvals + 3))
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim must be greater than k+2; using k+3 instead of ", opts.subdim);
+        ncv = uword(n_eigvals + 3);
+        }
+      else
+      if(opts.subdim > n)
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim cannot be greater than n_rows; using n_rows instead of ", opts.subdim);
+        ncv = n;
+        }
+      else
+        {
+        ncv = uword(opts.subdim);
+        }
+      }
+    
+    // Re-check that we are within the limits
+    if(ncv < (n_eigvals + 3)) { ncv = (n_eigvals + 3); }
+    if(ncv > n              ) { ncv = n;               }
+    
+    T tol = (std::max)(T(opts.tol), std::numeric_limits<T>::epsilon());
+    
+    uword maxiter = uword(opts.maxiter);
     
     // eigval.set_size(n_eigvals);
     // eigvec.set_size(n, n_eigvals);
@@ -384,7 +462,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::LARGEST_MAGN, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -393,7 +471,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::SMALLEST_MAGN, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -402,7 +480,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::LARGEST_REAL, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -411,7 +489,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::SMALLEST_REAL, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -420,7 +498,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::LARGEST_IMAG, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -429,7 +507,7 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
         {
         newarp::GenEigsSolver< T, newarp::EigsSelect::SMALLEST_IMAG, newarp::SparseGenMatProd<T> > eigs(op, n_eigvals, ncv);
         eigs.init();
-        nconv  = eigs.compute(1000, tol);
+        nconv  = eigs.compute(maxiter, tol);
         eigval = eigs.eigenvalues();
         eigvec = eigs.eigenvectors();
         }
@@ -452,8 +530,8 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
     arma_ignore(eigvec);
     arma_ignore(X);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     return false;
     }
@@ -466,14 +544,12 @@ sp_auxlib::eigs_gen_newarp(Col< std::complex<T> >& eigval, Mat< std::complex<T>
 template<typename T>
 inline
 bool
-sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpMat<T>& X, const uword n_eigvals, const char* form_str, const T default_tol)
+sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpMat<T>& X, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
   #if defined(ARMA_USE_ARPACK)
     {
-    const form_type form_val = sp_auxlib::interpret_form_str(form_str);
-    
     arma_debug_check( (form_val == form_none), "eigs_gen(): unknown form specified" );
     
     char which_lm[3] = "LM";
@@ -497,7 +573,6 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
       default:       which = which_lm;
       }
     
-    
     // Make sure it's square.
     arma_debug_check( (X.n_rows != X.n_cols), "eigs_gen(): given matrix must be square sized" );
     
@@ -513,13 +588,43 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
       }
     
     // Set up variables that get used for neupd().
-    blas_int n, ncv, ldv, lworkl, info;
-    T tol = default_tol;
+    blas_int n, ncv, ncv_default, ldv, lworkl, info, maxiter;
+    
+    T tol   = T(opts.tol);
+    maxiter = blas_int(opts.maxiter);
+    
     podarray<T> resid, v, workd, workl;
     podarray<blas_int> iparam, ipntr;
     podarray<T> rwork; // Not used in the real case.
     
-    run_aupd(n_eigvals, which, X, false /* gen, not sym */, n, tol, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
+    n = blas_int(X.n_rows); // The size of the matrix.
+    
+    // Use max(2*k+1, 20) as default subspace dimension for the gen case; same as MATLAB.
+    ncv_default = blas_int( ((2*n_eigvals+1)>(20)) ? (2*n_eigvals+1) : (20) );
+    
+    // Use opts.subdim only if it's within the limits
+    ncv = ncv_default;
+    
+    if(opts.subdim != 0)
+      {
+      if(opts.subdim < (n_eigvals + 3))
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim must be greater than k+2; using k+3 instead of ", opts.subdim);
+        ncv = blas_int(n_eigvals + 3);
+        }
+      else
+      if(blas_int(opts.subdim) > n)
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim cannot be greater than n_rows; using n_rows instead of ", opts.subdim);
+        ncv = n;
+        }
+      else
+        {
+        ncv = blas_int(opts.subdim);
+        }
+      }
+    
+    run_aupd(n_eigvals, which, X, false /* gen, not sym */, n, tol, maxiter, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
     
     if(info != 0)
       {
@@ -528,23 +633,26 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
 
     // The process has converged, and now we need to recover the actual eigenvectors using neupd().
     blas_int rvec = 1; // .TRUE
-    blas_int nev = n_eigvals;
+    blas_int nev  = blas_int(n_eigvals);
     
     char howmny = 'A';
     char bmat   = 'I'; // We are considering the standard eigenvalue problem.
     
-    podarray<blas_int> select(ncv); // Logical array of dimension NCV.
-    podarray<T> dr(nev + 1); // Real array of dimension NEV + 1.
-    podarray<T> di(nev + 1); // Real array of dimension NEV + 1.
-    podarray<T> z(n * (nev + 1)); // Real N by NEV array if HOWMNY = 'A'.
+    podarray<blas_int> select(ncv);      // logical array of dimension NCV
+    podarray<T>        dr(nev + 1);      // real array of dimension NEV + 1
+    podarray<T>        di(nev + 1);      // real array of dimension NEV + 1
+    podarray<T>        z(n * (nev + 1)); // real N by NEV array if HOWMNY = 'A'
     blas_int ldz = n;
-    podarray<T> workev(3 * ncv);
+    podarray<T>        workev(3 * ncv);
     
     dr.zeros();
     di.zeros();
     z.zeros();
     
-    arpack::neupd(&rvec, &howmny, select.memptr(), dr.memptr(), di.memptr(), z.memptr(), &ldz, (T*) NULL, (T*) NULL, workev.memptr(), &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, rwork.memptr(), &info);
+    T sigmar = T(0);
+    T sigmai = T(0);
+    
+    arpack::neupd(&rvec, &howmny, select.memptr(), dr.memptr(), di.memptr(), z.memptr(), &ldz, (T*) &sigmar, (T*) &sigmai, workev.memptr(), &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, rwork.memptr(), &info);
     
     // Check for errors.
     if(info != 0)
@@ -557,19 +665,19 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
     eigval.set_size(n_eigvals);
     eigvec.zeros(n, n_eigvals);
     
-    for (uword i = 0; i < n_eigvals; ++i)
+    for(uword i = 0; i < n_eigvals; ++i)
       {
       eigval[i] = std::complex<T>(dr[i], di[i]);
       }
     
     // Now recover the eigenvectors.
-    for (uword i = 0; i < n_eigvals; ++i)
+    for(uword i = 0; i < n_eigvals; ++i)
       {
       // ARPACK ?neupd lays things out kinda odd in memory;
       // so does LAPACK ?geev -- see auxlib::eig_gen()
       if((i < n_eigvals - 1) && (eigval[i] == std::conj(eigval[i + 1])))
         {
-        for (uword j = 0; j < uword(n); ++j)
+        for(uword j = 0; j < uword(n); ++j)
           {
           eigvec.at(j, i)     = std::complex<T>(z[n * i + j],  z[n * (i + 1) + j]);
           eigvec.at(j, i + 1) = std::complex<T>(z[n * i + j], -z[n * (i + 1) + j]);
@@ -580,7 +688,7 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
       if((i == n_eigvals - 1) && (std::complex<T>(eigval[i]).imag() != 0.0))
         {
         // We don't have the matched conjugate eigenvalue.
-        for (uword j = 0; j < uword(n); ++j)
+        for(uword j = 0; j < uword(n); ++j)
           {
           eigvec.at(j, i) = std::complex<T>(z[n * i + j], z[n * (i + 1) + j]);
           }
@@ -588,7 +696,7 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
       else
         {
         // The eigenvector is entirely real.
-        for (uword j = 0; j < uword(n); ++j)
+        for(uword j = 0; j < uword(n); ++j)
           {
           eigvec.at(j, i) = std::complex<T>(z[n * i + j], T(0));
           }
@@ -603,8 +711,8 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
     arma_ignore(eigvec);
     arma_ignore(X);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
+    arma_ignore(form_val);
+    arma_ignore(opts);
     
     return false;
     }
@@ -617,7 +725,7 @@ sp_auxlib::eigs_gen_arpack(Col< std::complex<T> >& eigval, Mat< std::complex<T>
 template<typename T, typename T1>
 inline
 bool
-sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpBase< std::complex<T>, T1>& X_expr, const uword n_eigvals, const char* form_str, const T default_tol)
+sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigvec, const SpBase< std::complex<T>, T1>& X_expr, const uword n_eigvals, const form_type form_val, const eigs_opts& opts)
   {
   arma_extra_debug_sigprint();
   
@@ -625,8 +733,6 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     {
     typedef typename std::complex<T> eT;
     
-    const form_type form_val = sp_auxlib::interpret_form_str(form_str);
-    
     arma_debug_check( (form_val == form_none), "eigs_gen(): unknown form specified" );
     
     char which_lm[3] = "LM";
@@ -649,7 +755,7 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
       
       default:       which = which_lm;
       }
-    
+
     const unwrap_spmat<T1> U(X_expr.get_ref());
     
     const SpMat<eT>& X = U.M;
@@ -669,13 +775,43 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
       }
     
     // Set up variables that get used for neupd().
-    blas_int n, ncv, ldv, lworkl, info;
-    T tol = default_tol;
+    blas_int n, ncv, ncv_default, ldv, lworkl, info, maxiter;
+    
+    T tol   = T(opts.tol);
+    maxiter = blas_int(opts.maxiter);
+    
     podarray< std::complex<T> > resid, v, workd, workl;
     podarray<blas_int> iparam, ipntr;
     podarray<T> rwork;
     
-    run_aupd(n_eigvals, which, X, false /* gen, not sym */, n, tol, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
+    n = blas_int(X.n_rows); // The size of the matrix.
+    
+    // Use max(2*k+1, 20) as default subspace dimension for the gen case; same as MATLAB.
+    ncv_default = blas_int( ((2*n_eigvals+1)>(20)) ? (2*n_eigvals+1) : (20) );
+    
+    // Use opts.subdim only if it's within the limits
+    ncv = ncv_default;
+    
+    if(opts.subdim != 0)
+      {
+      if(opts.subdim < (n_eigvals + 3))
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim must be greater than k+2; using k+3 instead of ", opts.subdim);
+        ncv = blas_int(n_eigvals + 3);
+        }
+      else
+      if(blas_int(opts.subdim) > n)
+        {
+        arma_debug_warn("eigs_gen(): opts.subdim cannot be greater than n_rows; using n_rows instead of ", opts.subdim);
+        ncv = n;
+        }
+      else
+        {
+        ncv = blas_int(opts.subdim);
+        }
+      }
+    
+    run_aupd(n_eigvals, which, X, false /* gen, not sym */, n, tol, maxiter, resid, ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, rwork, info);
     
     if(info != 0)
       {
@@ -684,21 +820,21 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     
     // The process has converged, and now we need to recover the actual eigenvectors using neupd().
     blas_int rvec = 1; // .TRUE
-    blas_int nev  = n_eigvals;
+    blas_int nev  = blas_int(n_eigvals);
     
     char howmny = 'A';
     char bmat   = 'I'; // We are considering the standard eigenvalue problem.
     
-    podarray<blas_int> select(ncv); // Logical array of dimension NCV.
-    podarray<std::complex<T> > d(nev + 1); // Real array of dimension NEV + 1.
-    podarray<std::complex<T> > z(n * nev); // Real N by NEV array if HOWMNY = 'A'.
+    podarray<blas_int>        select(ncv); // logical array of dimension NCV
+    podarray<std::complex<T>> d(nev + 1);  // complex array of dimension NEV + 1
+    podarray<std::complex<T>> z(n * nev);  // complex N by NEV array if HOWMNY = 'A'
     blas_int ldz = n;
-    podarray<std::complex<T> > workev(2 * ncv);
+    podarray<std::complex<T>> workev(2 * ncv);
     
     // Prepare the outputs; neupd() will write directly to them.
     eigval.zeros(n_eigvals);
     eigvec.zeros(n, n_eigvals);
-    std::complex<T> sigma;
+    std::complex<T> sigma = std::complex<T>(0);
     
     arpack::neupd(&rvec, &howmny, select.memptr(), eigval.memptr(),
 (std::complex<T>*) NULL, eigvec.memptr(), &ldz, (std::complex<T>*) &sigma, (std::complex<T>*) NULL, workev.memptr(), &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, rwork.memptr(), &info);
@@ -718,9 +854,9 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     arma_ignore(eigvec);
     arma_ignore(X_expr);
     arma_ignore(n_eigvals);
-    arma_ignore(form_str);
-    arma_ignore(default_tol);
-    
+    arma_ignore(form_val);
+    arma_ignore(opts);
+
     arma_stop_logic_error("eigs_gen(): use of ARPACK must be enabled for decomposition of complex matrices");
     return false;
     }
@@ -754,7 +890,8 @@ sp_auxlib::spsolve_simple(Mat<typename T1::elem_type>& X, const SpBase<typename
       X.soft_reset();
       return false;
       }
-    else if(A.n_rows < A.n_cols)
+    else
+    if(A.n_rows < A.n_cols)
       {
       arma_stop_logic_error("spsolve(): solving under-determined systems currently not supported");
       X.soft_reset();
@@ -773,7 +910,7 @@ sp_auxlib::spsolve_simple(Mat<typename T1::elem_type>& X, const SpBase<typename
     
     if(arma_config::debug)
       {
-      bool overflow;
+      bool overflow = false;
       
       overflow = (A.n_nonzero > INT_MAX);
       overflow = (A.n_rows > INT_MAX) || overflow;
@@ -903,7 +1040,8 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
       X.soft_reset();
       return false;
       }
-    else if(A.n_rows < A.n_cols)
+    else
+    if(A.n_rows < A.n_cols)
       {
       arma_stop_logic_error("spsolve(): solving under-determined systems currently not supported");
       X.soft_reset();
@@ -1150,21 +1288,23 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
     // not guaranteed to be new and delete.  See the comments in def_superlu.hpp
     superlu::NCformat* nc = (superlu::NCformat*)superlu::malloc(sizeof(superlu::NCformat));
     
-    if(nc == NULL)  { return false; }
+    if(nc == nullptr)  { return false; }
+    
+    A.sync();
     
     nc->nnz    = A.n_nonzero;
     nc->nzval  = (void*)          superlu::malloc(sizeof(eT)             * A.n_nonzero   );
     nc->colptr = (superlu::int_t*)superlu::malloc(sizeof(superlu::int_t) * (A.n_cols + 1));
     nc->rowind = (superlu::int_t*)superlu::malloc(sizeof(superlu::int_t) * A.n_nonzero   );
     
-    if( (nc->nzval == NULL) || (nc->colptr == NULL) || (nc->rowind == NULL) )  { return false; }
+    if( (nc->nzval == nullptr) || (nc->colptr == nullptr) || (nc->rowind == nullptr) )  { return false; }
     
     // Fill the matrix.
     arrayops::copy((eT*) nc->nzval, A.values, A.n_nonzero);
     
     // // These have to be copied by hand, because the types may differ.
-    // for (uword i = 0; i <= A.n_cols; ++i)  { nc->colptr[i] = (int_t) A.col_ptrs[i]; }
-    // for (uword i = 0; i < A.n_nonzero; ++i) { nc->rowind[i] = (int_t) A.row_indices[i]; }
+    // for(uword i = 0; i <= A.n_cols; ++i)  { nc->colptr[i] = (int_t) A.col_ptrs[i]; }
+    // for(uword i = 0; i < A.n_nonzero; ++i) { nc->rowind[i] = (int_t) A.row_indices[i]; }
     
     arrayops::convert(nc->colptr, A.col_ptrs,    A.n_cols+1 );
     arrayops::convert(nc->rowind, A.row_indices, A.n_nonzero);
@@ -1215,7 +1355,7 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
     // We have to create the object that stores the data.
     superlu::DNformat* dn = (superlu::DNformat*)superlu::malloc(sizeof(superlu::DNformat));
     
-    if(dn == NULL)  { return false; }
+    if(dn == nullptr)  { return false; }
     
     dn->lda   = A.n_rows;
     dn->nzval = (void*) A.memptr();  // re-use memory instead of copying
@@ -1241,6 +1381,11 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
       superlu::destroy_compcol_mat(&out);
       }
     else
+    if(out.Stype == superlu::SLU_NCP)
+      {
+      superlu::destroy_compcolperm_mat(&out);
+      }
+    else
     if(out.Stype == superlu::SLU_DN)
       {
       // superlu::destroy_dense_mat(&out);
@@ -1251,7 +1396,7 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
       
       superlu::DNformat* dn = (superlu::DNformat*) out.Store;
       
-      if(dn != NULL)  { superlu::free(dn); }
+      if(dn != nullptr)  { superlu::free(dn); }
       }
     else
     if(out.Stype == superlu::SLU_SC)
@@ -1278,7 +1423,7 @@ sp_auxlib::spsolve_refine(Mat<typename T1::elem_type>& X, typename T1::pod_type&
       if(out.Stype == superlu::SLU_NR_loc)  { tmp << "SLU_NR_loc"; }
       
       arma_debug_warn(tmp.str());
-      arma_stop_runtime_error("sp_auxlib::destroy_supermatrix(): internal error");
+      arma_stop_runtime_error("internal error: sp_auxlib::destroy_supermatrix()");
       }
     }
   
@@ -1291,8 +1436,9 @@ inline
 void
 sp_auxlib::run_aupd
   (
-  const uword n_eigvals, char* which, const SpMat<T>& X, const bool sym,
-  blas_int& n, eT& tol,
+  const uword n_eigvals, char* which, 
+  const SpMat<T>& X, const bool sym,
+  blas_int& n, eT& tol, blas_int& maxiter,
   podarray<T>& resid, blas_int& ncv, podarray<T>& v, blas_int& ldv,
   podarray<blas_int>& iparam, podarray<blas_int>& ipntr,
   podarray<T>& workd, podarray<T>& workl, blas_int& lworkl, podarray<eT>& rwork,
@@ -1309,22 +1455,21 @@ sp_auxlib::run_aupd
     // where we call saupd()/naupd() many times.
     blas_int ido = 0; // This must be 0 for the first call.
     char bmat = 'I'; // We are considering the standard eigenvalue problem.
-    n = X.n_rows; // The size of the matrix.
+    n = X.n_rows; // The size of the matrix (should already be set outside).
     blas_int nev = n_eigvals;
     
     resid.set_size(n);
     
-    // Two contraints on NCV: (NCV > NEV + 2) and (NCV <= N)
+    // Two contraints on NCV: (NCV > NEV) for sym problems or
+    // (NCV > NEV + 2) for gen problems and (NCV <= N)
     // 
     // We're calling either arpack::saupd() or arpack::naupd(),
     // which have slighly different minimum constraint and recommended value for NCV:
     // http://www.caam.rice.edu/software/ARPACK/UG/node136.html
     // http://www.caam.rice.edu/software/ARPACK/UG/node138.html
     
-    ncv = nev + 2 + 1;
-    
-    if (ncv < (2 * nev + 1)) { ncv = 2 * nev + 1; }
-    if (ncv > n            ) { ncv = n;           }
+    if(ncv < (nev + (sym ? 1 : 3))) { ncv = (nev + (sym ? 1 : 3)); }
+    if(ncv > n                    ) { ncv = n;                     }
     
     v.set_size(n * ncv); // Array N by NCV (output).
     rwork.set_size(ncv); // Work array of size NCV for complex calls.
@@ -1333,7 +1478,7 @@ sp_auxlib::run_aupd
     // IPARAM: integer array of length 11.
     iparam.zeros(11);
     iparam(0) = 1; // Exact shifts (not provided by us).
-    iparam(2) = 1000; // Maximum iterations; all the examples use 300, but they were written in the ancient times.
+    iparam(2) = maxiter; // Maximum iterations; all the examples use 300, but they were written in the ancient times.
     iparam(6) = 1; // Mode 1: A * x = lambda * x.
     
     // IPNTR: integer array of length 14 (output).
@@ -1351,13 +1496,19 @@ sp_auxlib::run_aupd
     info = 0; // Set to 0 initially to use random initial vector.
     
     // All the parameters have been set or created.  Time to loop a lot.
-    while (ido != 99)
+    while(ido != 99)
       {
       // Call saupd() or naupd() with the current parameters.
       if(sym)
+        {
+        arma_extra_debug_print("arpack::saupd");
         arpack::saupd(&ido, &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, &info);
+        }
       else
+        {
+        arma_extra_debug_print("arpack::naupd");
         arpack::naupd(&ido, &bmat, &n, which, &nev, &tol, resid.memptr(), &ncv, v.memptr(), &ldv, iparam.memptr(), ipntr.memptr(), workd.memptr(), workl.memptr(), &lworkl, rwork.memptr(), &info);
+        }
       
       // What do we do now?
       switch (ido)
@@ -1380,13 +1531,17 @@ sp_auxlib::run_aupd
           Col<T> in(workd.memptr() + ipntr(0) - 1, n, false /* don't copy */);
           
           out.zeros();
-          typename SpMat<T>::const_iterator x_it     = X.begin();
-          typename SpMat<T>::const_iterator x_it_end = X.end();
           
-          while(x_it != x_it_end)
+          typename SpMat<T>::const_iterator X_it     = X.begin();
+          typename SpMat<T>::const_iterator X_it_end = X.end();
+          
+          while(X_it != X_it_end)
             {
-            out[x_it.row()] += (*x_it) * in[x_it.col()];
-            ++x_it;
+            const uword X_it_row = X_it.row();
+            const uword X_it_col = X_it.col();
+            
+            out[X_it_row] += (*X_it) * in[X_it_col];
+            ++X_it;
             }
           
           // No need to modify memory further since it was all done in-place.
@@ -1421,6 +1576,7 @@ sp_auxlib::run_aupd
       }
     }
   #else
+    {
     arma_ignore(n_eigvals);
     arma_ignore(which);
     arma_ignore(X);
@@ -1438,6 +1594,7 @@ sp_auxlib::run_aupd
     arma_ignore(lworkl);
     arma_ignore(rwork);
     arma_ignore(info);
+    }
   #endif
   }
 
@@ -1534,6 +1691,12 @@ sp_auxlib::rudimentary_sym_check(const SpMat< std::complex<T> >& X)
       
       ++n_check;
       }
+    else
+      {
+      const eT A = (*it);
+      
+      if(std::abs(A.imag()) > tol)  { return false; }
+      }
     
     ++it;
     }
