@@ -1,12 +1,17 @@
-// Copyright (C) 2008-2015 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
-// Written by James Sanders
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup subview
@@ -16,7 +21,7 @@
 //! Class for storing data required to construct or apply operations to a submatrix
 //! (i.e. where the submatrix starts and ends as well as a reference/pointer to the original matrix),
 template<typename eT>
-class subview : public Base<eT, subview<eT> >
+class subview : public Base< eT, subview<eT> >
   {
   public:
   
@@ -25,8 +30,9 @@ class subview : public Base<eT, subview<eT> >
   
   arma_aligned const Mat<eT>& m;
   
-  static const bool is_row = false;
-  static const bool is_col = false;
+  static constexpr bool is_row  = false;
+  static constexpr bool is_col  = false;
+  static constexpr bool is_xvec = false;
   
   const uword aux_row1;
   const uword aux_col1;
@@ -43,6 +49,7 @@ class subview : public Base<eT, subview<eT> >
   public:
   
   inline ~subview();
+  inline  subview() = delete;
   
   template<typename op_type             > inline void inplace_op(const eT           val                        );
   template<typename op_type, typename T1> inline void inplace_op(const Base<eT,T1>& x,   const char* identifier);
@@ -91,6 +98,10 @@ class subview : public Base<eT, subview<eT> >
   template<typename functor> inline void transform(functor F);
   template<typename functor> inline void     imbue(functor F);
   
+  inline void replace(const eT old_val, const eT new_val);
+  
+  inline void clean(const pod_type threshold);
+  
   inline void fill(const eT val);
   inline void zeros();
   inline void ones();
@@ -112,13 +123,21 @@ class subview : public Base<eT, subview<eT> >
   inline eT&         at(const uword in_row, const uword in_col);
   inline eT          at(const uword in_row, const uword in_col) const;
   
+  inline eT&         front();
+  inline eT          front() const;
+  
+  inline eT&         back();
+  inline eT          back() const;
+  
   arma_inline       eT* colptr(const uword in_col);
   arma_inline const eT* colptr(const uword in_col) const;
   
-  inline bool check_overlap(const subview& x) const;
+  template<typename eT2>
+  inline bool check_overlap(const subview<eT2>& x) const;
   
   inline arma_warn_unused bool is_vec()    const;
   inline arma_warn_unused bool is_finite() const;
+  inline arma_warn_unused bool is_zero(const pod_type tol = 0) const;
   
   inline arma_warn_unused bool has_inf() const;
   inline arma_warn_unused bool has_nan() const;
@@ -159,13 +178,11 @@ class subview : public Base<eT, subview<eT> >
   template<typename T1> inline subview_each2< subview<eT>, 0, T1 > each_col(const Base<uword, T1>& indices);
   template<typename T1> inline subview_each2< subview<eT>, 1, T1 > each_row(const Base<uword, T1>& indices);
   
-  #if defined(ARMA_USE_CXX11)
   inline void each_col(const std::function< void(      Col<eT>&) >& F);
   inline void each_col(const std::function< void(const Col<eT>&) >& F) const;
   
   inline void each_row(const std::function< void(      Row<eT>&) >& F);
   inline void each_row(const std::function< void(const Row<eT>&) >& F) const;
-  #endif
   
   inline       diagview<eT> diag(const sword in_id = 0);
   inline const diagview<eT> diag(const sword in_id = 0) const;
@@ -174,10 +191,158 @@ class subview : public Base<eT, subview<eT> >
   inline void swap_cols(const uword in_col1, const uword in_col2);
   
   
-  private:
+  class const_iterator;
+  
+  class iterator
+    {
+    public:
+    
+    inline iterator();
+    inline iterator(const iterator& X);
+    inline iterator(subview<eT>& in_sv, const uword in_row, const uword in_col);
+    
+    inline arma_warn_unused eT& operator*();
+    
+    inline                  iterator& operator++();
+    inline arma_warn_unused iterator  operator++(int);
+    
+    inline arma_warn_unused bool operator==(const       iterator& rhs) const;
+    inline arma_warn_unused bool operator!=(const       iterator& rhs) const;
+    inline arma_warn_unused bool operator==(const const_iterator& rhs) const;
+    inline arma_warn_unused bool operator!=(const const_iterator& rhs) const;
+    
+    typedef std::forward_iterator_tag iterator_category;
+    typedef eT                        value_type;
+    typedef std::ptrdiff_t            difference_type;  // TODO: not certain on this one
+    typedef eT*                       pointer;
+    typedef eT&                       reference;
+    
+    arma_aligned Mat<eT>* M;
+    arma_aligned eT*      current_ptr;
+    arma_aligned uword    current_row;
+    arma_aligned uword    current_col;
+    
+    arma_aligned const uword aux_row1;
+    arma_aligned const uword aux_row2_p1;
+    };
+  
+  
+  class const_iterator
+    {
+    public:
+    
+    inline const_iterator();
+    inline const_iterator(const       iterator& X);
+    inline const_iterator(const const_iterator& X);
+    inline const_iterator(const subview<eT>& in_sv, const uword in_row, const uword in_col);
+    
+    inline arma_warn_unused const eT& operator*();
+    
+    inline                  const_iterator& operator++();
+    inline arma_warn_unused const_iterator  operator++(int);
+    
+    inline arma_warn_unused bool operator==(const       iterator& rhs) const;
+    inline arma_warn_unused bool operator!=(const       iterator& rhs) const;
+    inline arma_warn_unused bool operator==(const const_iterator& rhs) const;
+    inline arma_warn_unused bool operator!=(const const_iterator& rhs) const;
+    
+    // So that we satisfy the STL iterator types.
+    typedef std::forward_iterator_tag iterator_category;
+    typedef eT                        value_type;
+    typedef std::ptrdiff_t            difference_type;  // TODO: not certain on this one
+    typedef const eT*                 pointer;
+    typedef const eT&                 reference;
+    
+    arma_aligned const Mat<eT>* M;
+    arma_aligned const eT*      current_ptr;
+    arma_aligned       uword    current_row;
+    arma_aligned       uword    current_col;
+    
+    arma_aligned const uword aux_row1;
+    arma_aligned const uword aux_row2_p1;
+    };
+  
+  
+  class const_row_iterator;
+  
+  class row_iterator
+    {
+    public:
+    
+    inline row_iterator();
+    inline row_iterator(const row_iterator& X);
+    inline row_iterator(subview<eT>& in_sv, const uword in_row, const uword in_col);
+    
+    inline arma_warn_unused eT& operator* ();
+    
+    inline                  row_iterator& operator++();
+    inline arma_warn_unused row_iterator  operator++(int);
+    
+    inline arma_warn_unused bool operator!=(const       row_iterator& X) const;
+    inline arma_warn_unused bool operator==(const       row_iterator& X) const;
+    inline arma_warn_unused bool operator!=(const const_row_iterator& X) const;
+    inline arma_warn_unused bool operator==(const const_row_iterator& X) const;
+    
+    typedef std::forward_iterator_tag iterator_category;
+    typedef eT                        value_type;
+    typedef std::ptrdiff_t            difference_type;  // TODO: not certain on this one
+    typedef eT*                       pointer;
+    typedef eT&                       reference;
+    
+    arma_aligned Mat<eT>* M;
+    arma_aligned uword    current_row;
+    arma_aligned uword    current_col;
+    
+    arma_aligned const uword aux_col1;
+    arma_aligned const uword aux_col2_p1;
+    };
+  
+  
+  class const_row_iterator
+    {
+    public:
+    
+    inline const_row_iterator();
+    inline const_row_iterator(const       row_iterator& X);
+    inline const_row_iterator(const const_row_iterator& X);
+    inline const_row_iterator(const subview<eT>& in_sv, const uword in_row, const uword in_col);
+    
+    inline arma_warn_unused const eT& operator*() const;
+    
+    inline                  const_row_iterator& operator++();
+    inline arma_warn_unused const_row_iterator  operator++(int);
+    
+    inline arma_warn_unused bool operator!=(const       row_iterator& X) const;
+    inline arma_warn_unused bool operator==(const       row_iterator& X) const;
+    inline arma_warn_unused bool operator!=(const const_row_iterator& X) const;
+    inline arma_warn_unused bool operator==(const const_row_iterator& X) const;
+    
+    typedef std::forward_iterator_tag iterator_category;
+    typedef eT                        value_type;
+    typedef std::ptrdiff_t            difference_type;  // TODO: not certain on this one
+    typedef const eT*                 pointer;
+    typedef const eT&                 reference;
+    
+    arma_aligned const Mat<eT>* M;
+    arma_aligned       uword    current_row;
+    arma_aligned       uword    current_col;
+    
+    arma_aligned const uword aux_col1;
+    arma_aligned const uword aux_col2_p1;
+    };
+  
+  
+  
+  inline       iterator  begin();
+  inline const_iterator  begin() const;
+  inline const_iterator cbegin() const;
+  
+  inline       iterator  end();
+  inline const_iterator  end() const;
+  inline const_iterator cend() const;
+  
   
   friend class Mat<eT>;
-  subview();
   };
 
 
@@ -190,8 +355,9 @@ class subview_col : public subview<eT>
   typedef eT                                       elem_type;
   typedef typename get_pod_type<elem_type>::result pod_type;
   
-  static const bool is_row = false;
-  static const bool is_col = true;
+  static constexpr bool is_row  = false;
+  static constexpr bool is_col  = true;
+  static constexpr bool is_xvec = false;
   
   const eT* colmem;
   
@@ -209,6 +375,8 @@ class subview_col : public subview<eT>
   arma_inline const Op<subview_col<eT>,op_htrans> ht() const;
   arma_inline const Op<subview_col<eT>,op_strans> st() const;
   
+  arma_inline const Op<subview_col<eT>,op_strans> as_row() const;
+  
   inline void fill(const eT val);
   inline void zeros();
   inline void ones();
@@ -259,15 +427,12 @@ class subview_col : public subview<eT>
   
   inline subview_col(const Mat<eT>& in_m, const uword in_col);
   inline subview_col(const Mat<eT>& in_m, const uword in_col, const uword in_row1, const uword in_n_rows);
+  inline subview_col() = delete;
   
   
-  private:
-  
   friend class Mat<eT>;
   friend class Col<eT>;
   friend class subview<eT>;
-  
-  subview_col();
   };
 
 
@@ -280,8 +445,9 @@ class subview_row : public subview<eT>
   typedef eT                                       elem_type;
   typedef typename get_pod_type<elem_type>::result pod_type;
   
-  static const bool is_row = true;
-  static const bool is_col = false;
+  static constexpr bool is_row  = true;
+  static constexpr bool is_col  = false;
+  static constexpr bool is_xvec = false;
   
   inline void operator= (const subview<eT>& x);
   inline void operator= (const subview_row& x);
@@ -297,6 +463,8 @@ class subview_row : public subview<eT>
   arma_inline const Op<subview_row<eT>,op_htrans> ht() const;
   arma_inline const Op<subview_row<eT>,op_strans> st() const;
   
+  arma_inline const Op<subview_row<eT>,op_strans> as_col() const;
+  
   inline eT  at_alt    (const uword i) const;
   
   inline eT& operator[](const uword i);
@@ -329,40 +497,46 @@ class subview_row : public subview<eT>
   inline arma_warn_unused uword index_min() const;
   inline arma_warn_unused uword index_max() const;
   
+  inline typename subview<eT>::row_iterator        begin();
+  inline typename subview<eT>::const_row_iterator  begin() const;
+  inline typename subview<eT>::const_row_iterator cbegin() const;
+  
+  inline typename subview<eT>::row_iterator        end();
+  inline typename subview<eT>::const_row_iterator  end() const;
+  inline typename subview<eT>::const_row_iterator cend() const;
+  
   
   protected:
   
   inline subview_row(const Mat<eT>& in_m, const uword in_row);
   inline subview_row(const Mat<eT>& in_m, const uword in_row, const uword in_col1, const uword in_n_cols);
+  inline subview_row() = delete;
   
   
-  private:
-  
   friend class Mat<eT>;
   friend class Row<eT>;
   friend class subview<eT>;
-  
-  subview_row();
   };
 
 
 
 template<typename eT>
-class subview_row_strans : public Base<eT, subview_row_strans<eT> >
+class subview_row_strans : public Base< eT, subview_row_strans<eT> >
   {
   public:
   
   typedef eT                                       elem_type;
   typedef typename get_pod_type<elem_type>::result pod_type;
   
-  static const bool is_row = false;
-  static const bool is_col = true;
+  static constexpr bool is_row  = false;
+  static constexpr bool is_col  = true;
+  static constexpr bool is_xvec = false;
   
   arma_aligned const subview_row<eT>& sv_row;
   
-         const uword n_rows;     // equal to n_elem
-         const uword n_elem;
-  static const uword n_cols = 1;
+         const     uword n_rows;     // equal to n_elem
+         const     uword n_elem;
+  static constexpr uword n_cols = 1;
   
   
   inline explicit subview_row_strans(const subview_row<eT>& in_sv_row);
@@ -381,21 +555,22 @@ class subview_row_strans : public Base<eT, subview_row_strans<eT> >
 
 
 template<typename eT>
-class subview_row_htrans : public Base<eT, subview_row_htrans<eT> >
+class subview_row_htrans : public Base< eT, subview_row_htrans<eT> >
   {
   public:
   
   typedef eT                                       elem_type;
   typedef typename get_pod_type<elem_type>::result pod_type;
   
-  static const bool is_row = false;
-  static const bool is_col = true;
+  static constexpr bool is_row  = false;
+  static constexpr bool is_col  = true;
+  static constexpr bool is_xvec = false;
   
   arma_aligned const subview_row<eT>& sv_row;
   
-         const uword n_rows;     // equal to n_elem
-         const uword n_elem;
-  static const uword n_cols = 1;
+         const     uword n_rows;     // equal to n_elem
+         const     uword n_elem;
+  static constexpr uword n_cols = 1;
   
   
   inline explicit subview_row_htrans(const subview_row<eT>& in_sv_row);
