@@ -129,7 +129,7 @@ subview<eT>::inplace_op(const Base<eT,T1>& in, const char* identifier)
   
   arma_debug_assert_same_size(s, P, identifier);
   
-  const bool use_mp      = arma_config::cxx11 && arma_config::openmp && Proxy<T1>::use_mp && mp_gate<eT>::eval(s.n_elem);
+  const bool use_mp      = arma_config::openmp && Proxy<T1>::use_mp && mp_gate<eT>::eval(s.n_elem);
   const bool has_overlap = P.has_overlap(s);
   
   if(has_overlap)  { arma_extra_debug_print("aliasing or overlap detected"); }
@@ -687,8 +687,8 @@ subview<eT>::operator/=(const SpBase<eT, T1>& x)
   // This is probably going to fill your subview with a bunch of NaNs,
   // so I'm not going to bother to implement it fast.
   // You can have slow NaNs.  They're fine too.
-  for (uword c = 0; c < n_cols; ++c)
-  for (uword r = 0; r < n_rows; ++r)
+  for(uword c = 0; c < n_cols; ++c)
+  for(uword r = 0; r < n_rows; ++r)
     {
     at(r, c) /= p.at(r, c);
     }
@@ -1215,6 +1215,60 @@ subview<eT>::at(const uword in_row, const uword in_col) const
 
 
 
+template<typename eT>
+inline
+eT&
+subview<eT>::front()
+  {
+  const uword index = aux_col1*m.n_rows + aux_row1;
+  
+  return access::rw( (const_cast< Mat<eT>& >(m)).mem[index] );
+  }
+
+
+
+template<typename eT>
+inline
+eT
+subview<eT>::front() const
+  {
+  const uword index = aux_col1*m.n_rows + aux_row1;
+  
+  return m.mem[index];
+  }
+
+
+
+template<typename eT>
+inline
+eT&
+subview<eT>::back()
+  {
+  const uword in_row = n_rows - 1;
+  const uword in_col = n_cols - 1;
+  
+  const uword index = (in_col + aux_col1)*m.n_rows + aux_row1 + in_row;
+  
+  return access::rw( (const_cast< Mat<eT>& >(m)).mem[index] );
+  }
+
+
+
+template<typename eT>
+inline
+eT
+subview<eT>::back() const
+  {
+  const uword in_row = n_rows - 1;
+  const uword in_col = n_cols - 1;
+  
+  const uword index = (in_col + aux_col1)*m.n_rows + aux_row1 + in_row;
+  
+  return m.mem[index];
+  }
+
+
+
 template<typename eT>
 arma_inline
 eT*
@@ -1303,6 +1357,27 @@ subview<eT>::is_finite() const
 
 
 
+template<typename eT>
+inline
+arma_warn_unused
+bool
+subview<eT>::is_zero(const typename get_pod_type<eT>::result tol) const
+  {
+  arma_extra_debug_sigprint();
+  
+  const uword local_n_rows = n_rows;
+  const uword local_n_cols = n_cols;
+  
+  for(uword ii=0; ii<local_n_cols; ++ii)
+    {
+    if(arrayops::is_zero(colptr(ii), local_n_rows, tol) == false)  { return false; }
+    }
+  
+  return true;
+  }
+
+
+
 template<typename eT>
 inline
 arma_warn_unused
@@ -2134,135 +2209,131 @@ subview<eT>::each_row(const Base<uword,T1>& indices)
 
 
 
-#if defined(ARMA_USE_CXX11)
+//! apply a lambda function to each column, where each column is interpreted as a column vector
+template<typename eT>
+inline
+void
+subview<eT>::each_col(const std::function< void(Col<eT>&) >& F)
+  {
+  arma_extra_debug_sigprint();
   
-  //! apply a lambda function to each column, where each column is interpreted as a column vector
-  template<typename eT>
-  inline
-  void
-  subview<eT>::each_col(const std::function< void(Col<eT>&) >& F)
+  for(uword ii=0; ii < n_cols; ++ii)
     {
-    arma_extra_debug_sigprint();
-    
-    for(uword ii=0; ii < n_cols; ++ii)
+    Col<eT> tmp(colptr(ii), n_rows, false, true);
+    F(tmp);
+    }
+  }
+
+
+
+template<typename eT>
+inline
+void
+subview<eT>::each_col(const std::function< void(const Col<eT>&) >& F) const
+  {
+  arma_extra_debug_sigprint();
+  
+  for(uword ii=0; ii < n_cols; ++ii)
+    {
+    const Col<eT> tmp(colptr(ii), n_rows, false, true);
+    F(tmp);
+    }
+  }
+
+
+
+//! apply a lambda function to each row, where each row is interpreted as a row vector
+template<typename eT>
+inline
+void
+subview<eT>::each_row(const std::function< void(Row<eT>&) >& F)
+  {
+  arma_extra_debug_sigprint();
+  
+  podarray<eT> array1(n_cols);
+  podarray<eT> array2(n_cols);
+  
+  Row<eT> tmp1( array1.memptr(), n_cols, false, true );
+  Row<eT> tmp2( array2.memptr(), n_cols, false, true );
+  
+  eT* tmp1_mem = tmp1.memptr();
+  eT* tmp2_mem = tmp2.memptr();
+  
+  uword ii, jj;
+  
+  for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
+    {
+    for(uword col_id = 0; col_id < n_cols; ++col_id)
       {
-      Col<eT> tmp(colptr(ii), n_rows, false, true);
-      F(tmp);
+      const eT* col_mem = colptr(col_id);
+      
+      tmp1_mem[col_id] = col_mem[ii];
+      tmp2_mem[col_id] = col_mem[jj];
+      }
+    
+    F(tmp1);
+    F(tmp2);
+    
+    for(uword col_id = 0; col_id < n_cols; ++col_id)
+      {
+      eT* col_mem = colptr(col_id);
+      
+      col_mem[ii] = tmp1_mem[col_id];
+      col_mem[jj] = tmp2_mem[col_id];
       }
     }
   
-  
-  
-  template<typename eT>
-  inline
-  void
-  subview<eT>::each_col(const std::function< void(const Col<eT>&) >& F) const
+  if(ii < n_rows)
     {
-    arma_extra_debug_sigprint();
+    tmp1 = (*this).row(ii);
     
-    for(uword ii=0; ii < n_cols; ++ii)
+    F(tmp1);
+    
+    (*this).row(ii) = tmp1;
+    }
+  }
+
+
+
+template<typename eT>
+inline
+void
+subview<eT>::each_row(const std::function< void(const Row<eT>&) >& F) const
+  {
+  arma_extra_debug_sigprint();
+  
+  podarray<eT> array1(n_cols);
+  podarray<eT> array2(n_cols);
+  
+  Row<eT> tmp1( array1.memptr(), n_cols, false, true );
+  Row<eT> tmp2( array2.memptr(), n_cols, false, true );
+  
+  eT* tmp1_mem = tmp1.memptr();
+  eT* tmp2_mem = tmp2.memptr();
+  
+  uword ii, jj;
+  
+  for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
+    {
+    for(uword col_id = 0; col_id < n_cols; ++col_id)
       {
-      const Col<eT> tmp(colptr(ii), n_rows, false, true);
-      F(tmp);
+      const eT* col_mem = colptr(col_id);
+      
+      tmp1_mem[col_id] = col_mem[ii];
+      tmp2_mem[col_id] = col_mem[jj];
       }
+    
+    F(tmp1);
+    F(tmp2);
     }
   
-  
-  
-  //! apply a lambda function to each row, where each row is interpreted as a row vector
-  template<typename eT>
-  inline
-  void
-  subview<eT>::each_row(const std::function< void(Row<eT>&) >& F)
+  if(ii < n_rows)
     {
-    arma_extra_debug_sigprint();
+    tmp1 = (*this).row(ii);
     
-    podarray<eT> array1(n_cols);
-    podarray<eT> array2(n_cols);
-    
-    Row<eT> tmp1( array1.memptr(), n_cols, false, true );
-    Row<eT> tmp2( array2.memptr(), n_cols, false, true );
-    
-    eT* tmp1_mem = tmp1.memptr();
-    eT* tmp2_mem = tmp2.memptr();
-    
-    uword ii, jj;
-    
-    for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
-      {
-      for(uword col_id = 0; col_id < n_cols; ++col_id)
-        {
-        const eT* col_mem = colptr(col_id);
-        
-        tmp1_mem[col_id] = col_mem[ii];
-        tmp2_mem[col_id] = col_mem[jj];
-        }
-      
-      F(tmp1);
-      F(tmp2);
-      
-      for(uword col_id = 0; col_id < n_cols; ++col_id)
-        {
-        eT* col_mem = colptr(col_id);
-        
-        col_mem[ii] = tmp1_mem[col_id];
-        col_mem[jj] = tmp2_mem[col_id];
-        }
-      }
-    
-    if(ii < n_rows)
-      {
-      tmp1 = (*this).row(ii);
-      
-      F(tmp1);
-      
-      (*this).row(ii) = tmp1;
-      }
+    F(tmp1);
     }
-  
-  
-  
-  template<typename eT>
-  inline
-  void
-  subview<eT>::each_row(const std::function< void(const Row<eT>&) >& F) const
-    {
-    arma_extra_debug_sigprint();
-    
-    podarray<eT> array1(n_cols);
-    podarray<eT> array2(n_cols);
-    
-    Row<eT> tmp1( array1.memptr(), n_cols, false, true );
-    Row<eT> tmp2( array2.memptr(), n_cols, false, true );
-    
-    eT* tmp1_mem = tmp1.memptr();
-    eT* tmp2_mem = tmp2.memptr();
-    
-    uword ii, jj;
-    
-    for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
-      {
-      for(uword col_id = 0; col_id < n_cols; ++col_id)
-        {
-        const eT* col_mem = colptr(col_id);
-        
-        tmp1_mem[col_id] = col_mem[ii];
-        tmp2_mem[col_id] = col_mem[jj];
-        }
-      
-      F(tmp1);
-      F(tmp2);
-      }
-    
-    if(ii < n_rows)
-      {
-      tmp1 = (*this).row(ii);
-      
-      F(tmp1);
-      }
-    }
-  
-#endif
+  }
 
 
 
@@ -2448,12 +2519,12 @@ subview<eT>::cend() const
 template<typename eT>
 inline
 subview<eT>::iterator::iterator()
-  : M          (NULL)
-  , current_ptr(NULL)
-  , current_row(0   )
-  , current_col(0   )
-  , aux_row1   (0   )
-  , aux_row2_p1(0   )
+  : M          (nullptr)
+  , current_ptr(nullptr)
+  , current_row(0      )
+  , current_col(0      )
+  , aux_row1   (0      )
+  , aux_row2_p1(0      )
   {
   arma_extra_debug_sigprint();
   // Technically this iterator is invalid (it does not point to a valid element)
@@ -2594,8 +2665,8 @@ subview<eT>::iterator::operator!=(const const_iterator& rhs) const
 template<typename eT>
 inline
 subview<eT>::const_iterator::const_iterator()
-  : M          (NULL)
-  , current_ptr(NULL)
+  : M          (nullptr)
+  , current_ptr(nullptr)
   , current_row(0   )
   , current_col(0   )
   , aux_row1   (0   )
@@ -2755,7 +2826,7 @@ subview<eT>::const_iterator::operator!=(const const_iterator& rhs) const
 template<typename eT>
 inline
 subview<eT>::row_iterator::row_iterator()
-  : M          (NULL)
+  : M          (nullptr)
   , current_row(0   )
   , current_col(0   )
   , aux_col1   (0   )
@@ -2892,7 +2963,7 @@ subview<eT>::row_iterator::operator!=(const const_row_iterator& rhs) const
 template<typename eT>
 inline
 subview<eT>::const_row_iterator::const_row_iterator()
-  : M          (NULL)
+  : M          (nullptr)
   , current_row(0   )
   , current_col(0   )
   , aux_col1   (0   )
